(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101336,       1330]*)
(*NotebookOutlinePosition[    102530,       1365]*)
(*  CellTagsIndexPosition[    102486,       1361]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["Evolution Strategy\n\[Dash] A Short Introduction"], "Title"],

Cell[TextData[
"Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] April 1997 (copyright)"], 
  "Subsubtitle"],

Cell[TextData[{
  "Evolution Strategies (ES) have been invented during the 60s and 70s as a \
technique of evolutionary experimentation for solving complex optimization \
problems, mainly within engineering domains (",
  ButtonBox["Rechenberg 1973",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Rechenberg 1973"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["1989",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Rechenberg 1989"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["1994",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Rechenberg 1994"},
    ButtonStyle->"Hyperlink"],
  "; ",
  ButtonBox["B\[ADoubleDot]ck 1996",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "B\[ADoubleDot]ck 1996"},
    ButtonStyle->"Hyperlink"],
  "). The preferred ES data structures are vectors of real numbers. Specially \
tailored mutation operators are used to produce slight variations on the \
vector elements by adding normally distributed numbers (with mean zero) to \
each of the components. Recombination operators have been designed for te \
interchange or mixing of \"genes\" between two or more vectors. These \
recombinations range from simply swapping respective components among two \
vectors to componentwise computation of means."
}], "Text"],

Cell[" ", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000780001G`P10`4000010?ooooooc?ooZ_ooISLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc3/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol003lo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIV@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0o`L71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcV@l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<oa<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<aLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVA/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=VoalO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<b<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IVBLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000ob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A3<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0b@000?l0b@000?l0b@0009P01?l200;o
d`04o`800_m=0000V@000ol0o`020003o`3o0=<000?o0?l00P000ol0o`1<0000V@000ol000020003
o`3o0=<000?o00000P000ol0o`1<0000VP001ol0003o0?l0e0001ol0003o0?l0C00009P000Co003o
0P000ol0o`3B0004o`00o`8000?o0?l0C00009P01?l200?odP04o`800om<0000o`390000ZP04o`<0
0_oB00Co0`02ocX0002[0003o`3o008000?o0?l0d`000ol0o`020003o`3o03X0002P00;o0`04o`<0
00Oo0000o`3o0<P00_l300Co0`001ol0003o0?l0>P0009/01Ol00`3oo`070004o`00o`8000?o0?l0
``05o`030?oo00L000Co003o0P000ol0o`0j0000D`001?l0oom200;o0P000ol0000200;o1P001?l0
0?l20003o`3o07/000Co0?oo@P02o`8000?o00000P02o`H000Co003o0P000ol0o`0j0000D`000ol0
o`1000?o2P000ol0000500?o0`02og/000?o0?l0@003o`X000?o00001@03o`<00_lj0000E0000ol0
000L00?o0`02oaT00_l=0003o`0008T000?o00007003o`<00_lI00;o3@000ol000170000D`000ol0
o`0N0005o`000?l00P000ol0000C00?o00<0o`003@000ol000270003o`3o01h000Go0000o`020003
o`0001<00ol00`3o000=0003o`0004H0001C0004o`3ooad000Go0000o`020003o`0000h01Ol;0004
cR_>cPD00_n70004o`3ooad000Go0000o`020003o`0000h01Ol;0004cR_>cPD00_m60000M0001Ol0
003o008000?o00003002o`8000?o000020001@mb3g8?009b00<?00000P02ojP000Go0000o`020003
o`0000`00_l20003o`0000P000D?LPmb3`02LP033`0000800_m60000L`02o`<000Co003o2`03o``0
00P[cS4acS7>:`;>00=b000010000ol0002T00;o0`001?l00?l;00?o300022_><C7><Lh[0/h00g80
00040003o`0004<0001d0003o`0000800_l:00;o3@02LP03:g8?009b00L?LPla:c4[00H000?o0000
Y0000ol0000200;o2P02o`d00W800b]b3`02LP073g8?<B/a:`060003o`000480002200?o00<0o`00
2P001/h[c/h[cP8a00C><C5b0/h00g;>00050003o`000;800ol00`3o000:0006cR_>cR_>0S401<ha
<G82cP03L/h000D000?o0000@P0007d01Ol=000>_/kUc^G>LR]b<LhacS43cP03L/jZ00D00on]00Go
3@003[k>iLkUcW8[LS7><Lha0lh00g;>ZP0500?o@P0007/00_l20003o`0000`000DacS;U<P02i@09
LRH`9/hacS7>008a00CE<MDa1@02oj/00_l20003o`0000`000DacS;U<P02i@09LRH`9/hacS7>008a
00CE<MDa1@02od80001h00?o4P0021Ha<Ljnc[k>1S400`la3`02cP04Z/jZcPH000?o0000YP03oa80
00PF<C7>_/jncPHa00<?<@l00/h01:[>Z/h60003o`000400001f00;o5000237><LhbiC;U0/h00bH`
9P02<009c/FZaC7E<MDa00L000?o0000X`02oa@000PacS7><^Dbi@;>00<V<2H00S002Lk5Z/DaeC7E
<@070003o`0003l0001c00?o00<0o`004@00134F<AH2<@045[k>4`86134011HbcS82cP04Z/jZcPP0
00?o0000W`03o`030?l0014000@a5S4F0S4011JncQ<21P@a00@F</hb0/h01:[>Z/h80003o`0003h0
001C00;o6@05o`@000?o00003`02<@03cS7>008a00@6i@HC0PH021<a<C7><LjZ0/h01MG>1PK>00P0
00?o0000OP02oaT01Ol40003o`0000l00S400lhacP02<@041^D64`8600PC<C4acS7>ZP;>00GEcPH6
cP080003o`0003d0001C0003o`3o01H00_l20003o`0001D000S><Lk><LhacP8a00O><Lk><C0a00;>
00<aaJX00/D00lkUi@02i@P000?o0000OP000ol0o`0F00;o0P000ol0000E0008cS7>cS7><Lh2<@07
cS7>cS4`<@02cP03<LFZ00;500?>iND00^D80003o`0003d0001C0003o`3o01<00olJ00035S4F008a
00@F<AHa0PH00c464`021P0<<1Ha<AHa5S;>9S0V0PH00lh600070003o`0007d000?o0?l04`03oaX0
00<F<AH00S4011Ha5S421P03<@HC008600``5S4a5S4F</hV<2H21P03cPH000L000?o0000?00005<0
00?o0?l04@03oa/000G><Lk><@02cP03<Lha00<a00O><LhV<BHa00;>00LacZ[><Lha00?U00?>0000
1`000ol0001l0003o`3o01400olK0005cS7>cS400/h00c7><@03<@07cS7>9S4V<@02cP07<LjZcS7>
<@03i@03cP0000L000?o0000>`0005<000?o0?l03P03o`8000?o00006@001?DFmAH2<@045S46<@86
00La1Q<65S0F008a00<F<DH00S000bH`9P021P039PlV00P000?o0000O0000ol0o`0>00?o0P000ol0
000I0004mAKe5P8a00@F<@Ha0PH01c464`HF<1H00S400aHaAP02<0039S0V008600<V3bH020000ol0
000k0000D`000ol0o`0<00;o7`001J[>cS7>008a0/h9<@049S4V<@;>00TV<2K><Lhac^D01<h700;o
2`02o`<00_m[0003o`3o00`00_lO0005Z/k><Lh00S42cPTa00@V<BHa0/h02BH`9/hacS7>i@04cPL0
0_l;00;o0`02obX0001C00;o2006oa`000VUaLk5c/Ge<OD01c421P07<@Ha<BHa9P02<@03A/i600;>
00<ac/h01lh800;o0`04o`8000?o00000P000ol0o`1Z00;o2006oa`000VUaLk5c/Ge<OD01c421P07
<@Ha<BHa9P02<@03A/i600;>00<ac/h01lh800;o0`04o`8000?o00000P000ol0o`0Y0000FP03ob00
00<acS400/h03C7><ODFmAHa<1H`5S000PH0634[<30F<1H`cTK>A/i6IP5V0FHV3bH?IPT000?o0000
1`000ol000020003o`3o07400olP0003<Lha00;>00dacS7e5_DF<C0F<1H`008601Pa:c0`5S0F<<i6
cTK>AVH1IP5V9PlV3fH90003o`0000L000?o00000P000ol0o`0Y0000F002o`030?l001h000C5<JDa
0ZD02J[5Z/FZ<LhacP08<@079S4a9S4VEP02<0039S0V00S>00<?c/h02@000ol000070003o`000080
00?o0?l0K`02o`030?l001h000C5<JDa0ZD02J[5Z/FZ<LhacP08<@079S4a9S4VEP02<0039S0V00S>
00<?c/h02@000ol000070003o`00008000?o0?l0:@0005H00olP0007cS7>cS7><@02cP0A<LhamBHa
9S4`5S0F<34[<2/00S000aH`EP02J`04A/i6cP9V00<1IP400VH00`iV3P02IPT000?o00001P000ol0
00020003o`3o06d00olP0007cS7>cS7><@02cP0A<LhamBHa9S4`5S0F<34[<2/00S000aH`EP02J`04
A/i6cP9V00<1IP400VH00`iV3P02IPT000?o00001P000ol000020003o`3o02T0001C00?o8@000c75
Y@02a@:U00`aYJDaaJXacS7><Lh6<@039S4V008a00<VES000UH0130V<<l2LP07cPo>cPo>3`02cP03
:`0000H000?o0?l01`000ol0000200;oJ`03ob4000<aaJD00/D2Y@0<<JFU<LFZ<LhacS7>1S400bHa
9P02<@039UH`009F00@`9S3?0W801lh?c/h?cPl00/h00b/000060003o`3o00L000?o00000P02obX0
000c00?o0`02oa<01olQ008a0/h01<G>c/D3cP09<Lk>YLi@cS7>008a0S02cP08:c4[<LiFJeH2J`08
E/ibAW;>3hH2cP04Q/iV0@;>00<1:`001`02oeP00ol300;o4`07ob400S42cP04aLk>a@?>00Tac/jU
cU3><Lh00S42<0;>00P[<B/acUI[EP9[00QFcW96L/h?QP;>00B6cVH10/h00`4[000700;o=`0003@0
00Oo0000o`3o01400olU00079S4a9S4V<@02cP8a00H?<C4?cZD2cP07<BHaD2K>9P02cP03:c0[00;>
01=VJeI[cYK>ITI[UV^F3g9VLVIb00;>00<>cP002@000ol0001F0007o`000?l0o`0A00?o9@001bHa
<BHa9S400/h2<@063c4a3ljU0/h01c4V<E0VcRH00/h00b/`:`02cP0CIV]FJljFcVI6JiI[UPmbIW9V
LP02cP033/h000T000?o0000=00002d01?l30007o`000?l0o`0>00?o00<0o`008`00137><Lh2<@03
cS7>00CE0/h00c7>D002<@03D34a008[00@?9S0V0S001c4?IVH?IS000YH010nF3ll2cP8?0/h010o>
3lh2J`03:f/[00X000?o0000CP04o`<000Oo0000o`3o00h00ol00`3o000S0004<LhacP8a00?><Lh0
1=D2cP03<Li@008a00=@<C400R/010lV<2H2<007<@mVIPmV<002UP043iH?c`;>0Pl2cP043lh?cP9[
00<[Jb/02P000ol0000c0000=0001ol0003o0?l03003obL000@a9S4V0S4012Ha9S42cP03<Lha008a
00<?<JD00/h00g;>D002cP07D2K>cPo>IP02cP03IPnF00;>00BFcYH?0YH3IP0;LVIb9PlVcPk>3/h0
2002oeL000Oo0000o`3o00`00olW0004<BHa9P8a00@V<BHa0/h00c7><@02<@033c6U00;>00=bcU00
0/h01e0Vc/h?cVH00/h00fH?UP02cP04U/jF3`:F0fH02g9VLRH?9/h>cPk>00P00_le0000=0001ol0
003o0?l02@04obP00/h0137><Lh2<@03cS7>00GE00G><Lib3`02<@0<3c4[:`l[3bIV<6H?0VH00liV
cP02UP08cPo>3lh?cPl2cP033lk>00;>00E[:f/[cP090003o`0005D000Oo0000o`3o00T01?lX00;>
00@acS7>0S400lhacP05e@05cS7>LPl00S4030la:b/?:`lVIS1V3`9V00?>I/h00YH02<h?cPo>3lh?
0/h00`o>cP02cP05Jb][:lh02@000ol0000c0000<`02o`<00ol400Ko0P000ol0000R0004:bK>9P;>
00<acS400/h4<@0?eLkEc]G>LV]bJg8aLS5@00;>00e@c/k><<h?cVK>I/hV00;>00L?c/k>I/iV00;>
00=6c/h01lh:0003o`0005<00_l300?o1006o`8000?o00008P0012/VcRH2cP03<Lha00;>13403mG>
eLkEcW9[LV]b<G8aD002cP0=D<k>cS3>3liVcVK>9P02cP073lk>cVK>IP02cP03A/k>00O>2P000ol0
000b0000?@04obT000?>0Lh00/h01RK>cRHa9P8a00<V<BH00S402Lh?9PlVcPo>3`02cP033g8?009b
00O>L/k>L/ib00;>00<?cPl00/h019H1IP43IP0;9S0`9PlV3c4VcRH00/h00bH0000800;oG@04obT0
00?>0Lh00/h01RK>cRHa9P8a00<V<BH00S402Lh?9PlVcPo>3`02cP033g8?009b00O>L/k>L/ib00;>
00<?cPl00/h019H1IP43IP0;9S0`9PlV3c4VcRH00/h00bH0000800;o<P0003X00olZ0005LPmbLR/0
0W801lhVc/hVcS400/h00c7><@08cP03J`l?00@?0/h00`o>LP03LP@?00@>9/hV2<h014K>cTH4cP03
<Lk>00;>00<a00002002oeX00olZ0005LPmbLR/00W801lhVc/hVcS400/h00c7><@08cP03J`l?00@?
0/h00`o>LP03LP@?00@>9/hV2<h014K>cTH4cP03<Lk>00;>00<a00002002oc80000h00?o9`0017;>
L/h2D004cU3>0@?>00HVc/k><BH2<@0:9S4V<C0V3bH?9P9V00K>D<k>3fH2QP03LXIb009b00?>L/h0
0W801<ib3`l29P070FH1IRHa9P02<0039Q8V008a00<V<BH00S000bH`000:0003o`0005D00olW0004
L/ibcP9@00C>D<h10lh01RK>c/ha9P8a00XV<BHa<2H?9PlV0VH01/i@c/h?IP:600=bQW800W800lib
cP02LP04cW8?3`8V00L1IP5V9S4V008`00<V4RH00S400bHa9P02<0039S0000X000?o0000;`0003D0
0ol20003o`00028000<[LR/01W800`mb3`03LP03:bKE00?E00Hac/hacS42cP039/k>00;>00P?cPl?
cPo>3`;>00<?<BH00W800b]b:`023`03:lk>00O>00<acTH00/h00c0V<002cP03<Lha00;>00<acP00
2P000ol0000D00?o>`03o`8000?o00008P000b]b:`06LP033g8?00=b00<[9]D00mD01S7>cS7><@;>
00<Vc/h00/h020o>3`o>3lh?0/h00`la9P02LP03:g8[008?00<[c/h01lh00c7>AP02cP03<2H`00;>
00<acS400/h00c7>000:0003o`0001@00olH0000<006obH01?D3LP0>cW;>LU2RD:9bXS5bc]D2cP07
eC4acS7><@02cP039S3>00;>00=Vc/h00/h03FK>IRKn9_hVoRK>L/h00W800c5b<@04cP0;A/k><Lha
cQ8`4S000/h00b_>:`02cP03<Lk>00/000?o00005002ocH01_lV00Ce0g803/ibcW9@XU2RLZ8aL/kE
0/h01mDa<LhacS400/h00bH`cP02cP03I/k>00;>00eVcVHVoRKn9_hVcW;>009b00<aLS401<h02dK>
cS7><LhB<18`00;>00<[cR/00/h00c7>cP0;0003o`0001@00_lH00004`05o`800_lB00?o0P000ol0
000T00;>0_D01<kecW84<@:R00<aLS400W80135b<G82cP07<Lha<2H`9P02<004I/mVc`9V00G>I/k>
IP039P05o/knc_h01C403W8aLS5bcS7><Lha9S4V0Q8022HB9Q8`9S0V0S0012H?9Pl;0003o`0001@0
00?o00005`05o`800_lB00?o0P000ol0000T00;>0_D01<kecW84<@:R00<aLS400W80135b<G82cP07
<Lha<2H`9P02<004I/mVc`9V00G>I/k>IP039P05o/knc_h01C403W8aLS5bcS7><Lha9S4V0Q8022HB
9Q8`9S0V0S0012H?9Pl;0003o`0001@000?o00005P0001@000Ko003o0?l20003o`0000`00ol[0003
cS7>00Ce00>Z<C400S400lha<@02cP07X/jR<LhacP02e@0=<JG>cS7><LhVcRK>9P02cP07I/iVcS7>
<@02cP039PHa008600W><LhacR_>:c400TH01356<Lh2<@0;cS4`<2H`<Lh[cR/01/h;0003o`0001<0
00?o0?l06@001_l00?l0o`8000?o00003003ob/000?><Lh01?D00jXa<@02<@03cS4a00;>00NRcZ8a
cS7>00;E00daYLk><LhacRK>9/hV00;>00MVcVK><Lha00;>00<V1S400PH02LhacS7>:lh[<@02AP04
<DHacP8a00_><C0`9S0acR_>:`06cP/000?o00004`000ol0o`0G00003P05o`8000Go0000o`020003
o`0000X00ol00`3o000Y000:cRK>9/kec_Dam@@a0Z800c5b<@02LP0><G8aTC7>D<i@<2H`9S02IP07
cfK?cVK>IP02cP03:bHV008V2c405`Ha1/hacS7><BHa9S4B9Q96cTHV<2H?008V00<?9Pl030000ol0
000B0003o`3o01<01Ol20005o`000?l00P000ol0000:00?o00<0o`00:@002/hVcRK>mLke<OD4<@:R
00<aLS400W803S5b<I4acU3>D30V<2H`0VH01lmVcliVcVH00/h00b/V9P029P/a01L6<@K><LhacS4V
<BHa4RHBA/i69S0V3`029P033bH?00`000?o00004P000ol0o`0G00005P001?l00?l20003o`0000L0
0ol^000:9/k><LhamJXaZPLa01O><J;>SC7><LhaYC6U<LhacPo>3lhVcP02IP03cVK>00=V00?><Lh0
0S402@Ha1PK><LhacP05<@04AS56<@;>00<acS400S001c5V<Lh[cV/01lh<0003o`0000@00_l:00;o
00<0o`006P001?l00?l20003o`0000L00ol^000:9/k><LhamJXaZPLa01O><J;>SC7><LhaYC6U<Lha
cPo>3lhVcP02IP03cVK>00=V00?><Lh00S402@Ha1PK><LhacP05<@04AS56<@;>00<acS400S001c5V
<Lh[cV/01lh<0003o`0000@00_l:00;o00<0o`005P0001<000Oo0000o`3o008000?o00000P06obh0
00<V<1801Lh01_FZmJ[eZP<a00CeXS5R0S42S@0<TC6ATLhacS7>3lh?0lh5IP08cVK>cVHV<BH2m@8a
0PH00jXa<@02Y@06<@Ha1/ha1<h022Ha9S4VI/iV0/h00f_>J`02cP05Jlh13lh02`03o`D000?o0?l0
9@001ol0003o0?l00P000ol0000200Ko;P000bH`4P05cP06mJ[eZ_FZ0c401?FR<F82<@:=00bA<I6A
cS7><Lh?cPl3cPEV00S>I/k>IRHa9P;e0S421P03ZS4a00:U00Ha1S46cS44cP089S4V<BIVcVH2cP03
Jli[00;>00E[cP4?cP0;00?o1@000ol0o`0T00005003o`<00_l300?o<P0022HB9Q;>9/hF0S00137e
<OD2<@06OS5nHS5R1S42T@04<E3>AP;>00``9S2VIPmV3fI6cR/2cP04:lkecP;e00O><C7e<ODa00:U
00Pa1S46<AK>5P;>01<V<BHacTK>A/ibQPmV3fH?9/hV00;>3@000ol000020003o`3o02H00ol300;o
0`03oc8000PV4RHBcRK>5P8`00@amC7e0S401WhaOV8aHPHa0Y40135@cTH2cP0<<2H`YVH?IPmVA/h[
0/h012_>mLh2m@07cS4amC7e<@02Y@08<@Ha1S4FcQH2cP0C9S4V<Li6cTK>LXH?IPmV3bK>9P02cPd0
00?o00000P000ol0o`0T00007003o`8000?o0000;`001dH`9S0V<<h013402JXaZS7e4oDCm@05<@:=
00PaSLhaLR]b:`9b00g>3lk>3lh`IUH`EVHa009V1c400`JZZP08<@8`00<acS400/h02c7>ATH`<FHa
I/mV00=[00L`J`4?cLk=00`000?o00000P000ol0o`0^00?o0P000ol0000_0007AS0V<2H`cP04<@09
ZS6Z<ODCmA?e00Da0Xd0236=cS5b:g8[0W803Lh?c/h?cS1VES1FIS400VH7<@031ZZZ00Pa0S000c7>
<@02cP0;<Li6AS0aIS5VcfH00f/01c1[0@o=c/d030000ol000020003o`3o02@0000J00?o=@02<003
9Q8V008B00<F<1H00S003S7e<OFZ<GhaOV8aHS5R0S400lha9P02cP039/i600;>00Q69ZJVIZIV3`96
00P`A/k>1S06cP;e00O>1_Ge<ODa00:U00@aYC4F0S401lhFc/hF<EH00/h015K>AW82QP07LPm[J`o>
3`02cP033lh?00/00_l30003o`3o02`00ole008`00<V4RH00Q800aH`5P02<00><ODamJXaOS5nHS5R
<F82<@03cS4V00;>00<VcTH00/h024HVYZIVYVH?0TH02316c/h6<0K>0_D01lh6mODamC400ZD0136U
<AH2<@07cQK>cQHaEP02cP04E/i6LP:600Mb3f][3lh?00;>00<?cPl02`02o`<000?o0?l0900001L0
0ol00`3o000d0009A/k>ARH`9S0[00Ha00NZ<JXCmA?e00@a00HFcQK>5/h2LP03<G8[009b0Pl2cP03
3lh?009F00D`ES1FIP09<@:Z00<aZS400S400nD`:`02<003:lha00;>00M6<4I6<9K?009V00??IV/0
0VH01LiVcVK=00;>00<?cP002@02o`<00_lZ00?o00<0o`00=0002DK>cTHV<2H`:`06<@07ZS6Z4oDC
m@04<@065/hFcQK>0W800c5b:`02LP8?0/h00`o>3`02EP05<5H`EVH02C42ZP03<JXa008a00?U<2/0
0S000b_><@02cP07AS16AS2Fc`02IP03cfI[009V00G>I/iVc@02cP033lh000T00_l300;o9@0001D0
0ol30003o`00034000?><2H00S0022HB9Q8[9S0F0S000aKe<@02ZP03<Gha009n00<aHS400c400lha
cP02cP039/hV00;>00QbcZJVI/iVcP9600<`A/h00PH03C06<?D6<@HamC7e<JD00/h00lG>5P02<@8F
00G>LRIbEP02cP0DU/jFLXH?J`m[cPo>3liVLPib3W8;0003o`0002X00ol30003o`00034000?><2H0
0S0022HB9Q8[9S0F0S000aKe<@02ZP03<Gha009n00<aHS400c400lhacP02cP039/hV00;>00QbcZJV
I/iVcP9600<`A/h00PH03C06<?D6<@HamC7e<JD00/h00lG>5P02<@8F00G>LRIbEP02cP0DU/jFLXH?
J`m[cPo>3liVLPib3W8;0003o`0002L0000B00Co8P00336RXS6=<HfR<J8aO@;=00QlcWa[cV_>LP;>
00Ibc/k>A/h3<003:c0a008a00?>ZZX00jX01?DamOD6<@03cS7>009b00onc_kncW;>L/iVcVK>ETH0
1<h010Ha1S421P07<@HamJ[eZP02i@04c^G>:`8a00L[IW9bcW8`00;>00BFcYJF0f/00iH`UP02cP07
I/iV9S7><@02LP/00_lW00Co8P00336RXS6=<HfR<J8aO@;=00QlcWa[cV_>LP;>00Ibc/k>A/h3<003
:c0a008a00?>ZZX00jX01?DamOD6<@03cS7>009b00onc_kncW;>L/iVcVK>ETH01<h010Ha1S421P07
<@HamJ[eZP02i@04c^G>:`8a00L[IW9bcW8`00;>00BFcYJF0f/00iH`UP02cP07I/iV9S7><@02LP/0
0_lW000050000ol0000O00Da00W><J8aXS6R<J800V40236mcLg>L/ib1B/01<h?cPl2<004:c0[<@;>
00<aZS400ZX02?DCmC4`5S0F0S001/h?c/h?cP8?0W853`09cPo>E/hacS7>00Xa00fZcS7>iC;U<^G>
3lh?00?>00G?cPnF3`04IP09J`mV3fK>3lh?00;>00<VL/h00lh:00;o:@000ol0000O00Da00W><J8a
XS6R<J800V40236mcLg>L/ib1B/01<h?cPl2<004:c0[<@;>00<aZS400ZX02?DCmC4`5S0F0S001/h?
c/h?cP8?0W853`09cPo>E/hacS7>00Xa00fZcS7>iC;U<^G>3lh?00?>00G?cPnF3`04IP09J`mV3fK>
3lh?00;>00<VL/h00lh:00;o9`0003@00c401lhacZ8aXS400Xd0136R<J82c@0=OLilO<i[cV]bcW;>
LP02IP07cVH[:bH[9P02<@035S4a00:Z00@aZS4C0PH01a<a<C5VLVH00W800fK?3`02c@033lg>009b
0/h01VI[cRK>9P;>01<6<1K><@Ha1S469UHVE/G>aLhV009V01;>I/ib9PnF3lh?IPmV3hH`US02IP07
<6H`<2H`9P02cP039/h000/000?o0000AP03<@07cS7>XS6R<@02S@04<J8aXP;=00emcWalcV_>Jg;>
L/ib009V00O>IR/[9R/V008a00<F<C400ZX0136Z<A<21P074c4a<FIbIP02LP03I/l?00;=00<?cLh0
0W82cP06IV_>9/hV0/h04`H`5/ha1S46<@HVERIFaLk5cRH00VH04/iVcW8V3iH?cPmV3fH?QS2F<09V
00L`IS0`9S0V00;>00<VcP002`000ol0000T0000<0001S7><LhacPDa00C><J8a0j801S6R<F4aH@;=
00>mL/h00/h43`04cPo>3`S>00<aZS400ZX04S4`<C4`<C0F<<hV3liV<6H`IP9b00<?LW800W802C5@
<C7><LhacP09<@04cS7><@;>00<bcS400/h02Po>3lh?cPo>3lh4IP;>0fH2cP03I/hV00;>00<V:lh0
0/h00c40000:0003o`00048000HacS7><Lh5<@04cS6R<@>R00HaXS5Q<F42c@03_G;>00;>10l01<h?
cPl8cP03<JXa00:Z018a<34a<34`5S3>9Po>IS1V<6H2LP033g9b009b00TaD34acS7><Lh02C401<ha
cS42cP03</ha00;>00X?cPo>3lh?cPo>16H2cP=V0/h00fK>9P02cP039R_>00;>00<a00002P000ol0
000T0000;@000lda<@07<@0BcS7>XS6R<Hf0IF4aHJ8aXS4`0/d00c3=LP03LP04cW9bIP;>010?9RH?
9Pla5S4FZQ<F4aHC0PH021<6<LiVcVIb0Pl05/l?3g;>L/ibmLkecV_>9/hVcS8FcQH2cP0=1S46<LhV
ERIF9PlV3`029P04I/iV3P@?0/h010mVQPl2QP03cVH`009V00La:c0`9R/a00;>00<V<BH02`000ol0
000o0003cC4a00La01;><LjR<J8aSH1UHC5QXS6R<C02c@03<<eb00=b00C>LW9V0/h040lV9PlV3c4F
<AJZ4aHC5Q<21P084`HacVK>IW823`0Fc`l?L/ibcW;ec_G>JlhVcRK><QK>5P;>00d6<@HacRIF9UHV
3bH?008V00AVcVH>10l2cP043fJ63`:600?>IS000VH01c4[<30V:c400/h00bHa9P0;0003o`0002@0
000Q000?cPo=c/ebTG;=P<dacC7=00Da0/h5<@07OX0aP620<@02H@BR00XacC7=<LibcW8?17800`o>
cP03cP04<Li@cP8a00@`<C0a0PH00c7><004cP03IYH`009V00?>IW800W801/ibLW;>J`C>00FniNG>
<@02cP8a00MFc/iFcS5V00?>00@acW:A0W87cP089VK>I/h[cR/2cP0>:c4[<Lha:c4[<LhacS4:00?o
<`003lh?cLk=LY5bcH3=<Ldac@05<@;>1C401gj0<H1PP3400V44XP0:<LdacC7>L/ib3`Ab00<?c/h0
0lh0137>D<h2<@04<34`<@8600<acS001<h00fJF<002IP03cVIb009b00K>LW9bcV/4cP05_^GUcS40
0/h2<@07E/k>E/haIP03cP04<LibT@9b1lh022IVcVK>:lh[0/h03R/a:c7><B/a:c7><Lha2P03ob@0
000P00;>00T?cW8?LY4aTLh00/d0337><C7><LhacV8aI@9n00B0OX1n0V003/iPP83><J8aXS4[LR]b
1<h2LPC=00d>c/k>mC7e<ODa<34`008a00C>9/hV0/h010mV3iH2cP073lkUL/ibcP02LP03XW8a00:m
00>niKh00^D4<@03cUH`009F00AV0LiV0/h00g8?cP02cP033lh?00;>00`a0Lk>3lh?IS4V<BH2<@04
:c4[<@D[00@acS7>0S4<0003o`0002l00/h02@o>LPmbTC6AcP02c@0<<Lha<LhacS7>HS5U0Wh0181n
P7h2H00>cV20P<haXS6R<B]b:g84cP9b1<d03@k>c/ke<ODamC4`<C000S401<hVcRH2cP043fH?UP;>
00L?c^EbcW;>009b00>RLS400[d00kkU_P02i@@a00?>ES000UH016H1cVH2cP03LPo>00;>00<?cPl0
0/h03341c/h?cPmV<BHa9P8a00@[<B/a1B/0137><Lh2<@`000?o00008@0001h000L[3b_>3lh?00;=
00?>L/h00X000c7=<@02c@<a0X000c60<@06<@04P6F0I@9Q00@aHC6R0S400b_>:`02cP033lh>00;>
01`>LX20cKebcW;>D<i@cQHC5Q<6IS1V<<jFIYH?0XH00`mV_P03cP0<<LhacV[>J[g>_Lhb0/h01c8F
c/iVcUH00/h01@o>3`mb00D?0W802c4FL/ibcW;>9/hV00;>01@[cR/V<B/a:c4[<B/a_c4V<BI6:``0
00?o0000;@001b/?:lh?cPl00/d00libcP02P003<Lda00;=0c42P003<H0a00Ha00B0IH1U0V40135Q
<J82<@03:lh[00;>00<?cPh00/h070ibP83=_G;>L/i@cU3>5Q<F4`IV<6H`cYIVUPl2QP033fJn00?>
00`acS7>J/iZ_LjmcS82cP07<QK>cVK>EP02cP053lh?3g801@l2LP0;<AIbcW;>L/hVcRH00/h052_>
:bHa:c4[<B/a:c6o<BHa9TH[30000ol0000Q00007@002C0?<0mb<G8aS@02XP03OHem00;=0/h01S6R
HS5R<@9R00`aHWinP7j0OX1PcV02P003cS4a00@a00Mb:g8V:g8[009b00RnP7:0XY7=cP8a00Oe<ODa
<34`00?>00<VcRH00R/00`o>UP02cP08US;UiC;UL/h2LP03XW:R00:m00<a_Kh00^D00kha9P02cP03
9/iF009V00<13`401Lh04/EbcW;>LP4a0C7><LhacS4V<@8V00Da:c4[9P03:`049S4acP@a3@000ol0
000[0009<0l`3g8aLS6=00:R00=mSGd00/d2cP06<J9R<F8a0V80335ROWj0OX1nP63>H0:000?><C40
13401g8[LRH[LR/00W802;j0LX2RTLg>0S401oDamC4`<C000lh00bK>9P02:`033ljF00;>00RF<^GU
<^EbcP9b00>RLZ800[d00c6m_P02i@03_S4V00;>00<VcUH00VH00`4?0@05cP0BaG;>L/ib0C41<Lha
cS7><BHa0RH01C4[<B/V00<[00@V<C7>134=0003o`000200000L0003cPo>008?0/h02j;>XVXaP360
XS6R00@a00J0<H20<H07<@05P6F0IH000S400c8a9P02<@089S4[<2H`cPh2cP05</k=cLh00j82LP08
D<i@cQH?IPl2IP03<6I600:[00?>QPl00XH00fHV_P02cP03_/k>008a00QZcVZmc[g>_@;>00`[I/k>
I/h?I/h?D0l2cP04U/h?<@;>01TF<AIbcW;>LWhVORIncR/V<BHa:c4[0B/a008[0[l00bI6:`02AP`0
00?o0?l0:`000lh?cP023`;>00^RcZ9Z<H0aP:8aXP04<@06P360P3601c401H1UP6F0008a00<b<BH0
0S4022Ha:c0V<<h>0/h01C;>cLg>00>R0W80253>D<hF3fH?0VH00c1VAP02Z`03cXH?00:600=V9[h0
0/h00kk>cP02<@08J/iZ_Ljmc[d2cP0<:fK>cVK>3fK>3e0?0/h019K>3c42cP0I5S4FL/ibcW9n9WhV
O/h[9S4V<B/a:`4[<@02:`:o00<VAR/00TH<0003o`3o0240000G000Ao/knc_iV3fH?IW;>LS6RSJ80
0Xd00h2R<@02XP05OZ:RP6800X000f:0HP02OP09IGj0OX1PcV0a009n00<aOS400c401c3>cRK>:c80
0/h02[k>L/f0LZ:AX/02XP05mG;>cVH01<h01Z]6cYK>UP?>00IVcVKUc^D2<@04SC7=S@;=00jmcKg=
L/h[cR_>3j/?Z`9V00=[c/h00/h00c75a@02cP04<G;>LPDa00@VORIn0S4022Ha9S4[9R/V0R/02[l[
_kmFAS56<DH=0003o`0002@0017nc_k>oVH?IPmVL/ib<J:=XP02S@03P:8a00:R00EnXZ:0HP02P003
HX1R009n00UUOX1nP63>H3400Wh00c5n<@03<@07<<k>9/h[<P02cP0:_/ibcH1bXY6R`0:R00GeL/k>
IP04cP06ZdK>U/jF0lh01VK>I^G>i@8a00B=<Lf=0/d03[g=_LebcR_>:lh?Z`n[0VH00f_>cP02cP03
<LG500;>00@aL/ib1C4012In9Wh2<@089S4V<B/V:bH2:`0:_b^o_eI6<DHaAPd000?o00007`0001L0
10l2IP0;cfK?3j8aXV4aHJ800Xd01Wf=4gdCOP:R00<aHS400V803C5R<GiUOX1nHWhaOS400Wh02C5n
<C4`9S0VcP029P03<2Jn00>n1C43XP03TJ:A00=b00c>I/k>I/h?UPnF3bH2cP08<LhaiC7e<OD3<@0<
SLg=SLfmcKeb:g;>0W802:/?0@l`3c0?0/h00c7>a@02a@05mA<a<A<01C401<ha<Lh49P04<@4V4`8V
00Hb<BHaE[l4<@030@0000`000?o00001003o`<00_lG00@?0VH02lmVc`nR<J9Q<F6R00:=00ImSA=m
4gh2XP03<F8a009R00daHS5nIGj0OV9n<Gha009n00TaOS4a<2H`9/h00RH00c0V_P03_PDa0j800i6R
T@03LP0<cVK>cVK>3iH?UPlV0/h0237><NDamC7e0c4038g=cHg=_LfmLR]bcP9b00R[3`4?<0l`3`;>
00<ac/D00/D01ODC<C4C00Da00C><C7>12H013419Q<29P06<S4V<EJo13400`40000<0003o`0000@0
0ol300;o4P0001P00/h01Po>cPm[3`9b00PaLS5nXX2=<@:000<aXS400c40280aP80aP3600S400gda
E@02<@03:S4Z008a01/b<C8a9Q8V4S0[4b/C</hb<LEQ<F4aHI4aTJ800/002<ebcG;>3lh?0/h04YK>
9/iV9VHVIQ<a4c4CSC6=<@9m00<aOLh00[d00lh?3`033`07<@mVJfI[1P02<@075S4F<ODam@09<@03
OQHa008a00dV<BI6:`4[0OEV_b^o009F00=6:dH00TH00bH0000:00?o1P001ol0003o0?l06002cP06
3lk>3f/?0W80235b<GjRP8da0X000c6R<@03<@08P360P360<H02<@03OC5E008a00<Z<BX00S406c8a
<S4V4RHB<2/C:a<bcS8aaF4aHC5QTC6AXP02`008cG;=L/h?cPl2cP0BU/hVcVHVIRIV4c4C<A>=<Hda
0Wd00c5mcP02_@03cPl?00<?00La3fI[IV/6008a00LF<AHamC7e00Ta00=n5S400S403BHa9TH[0B/1
mFJo:kl00UH00dH[AP02AP039P0000X00ol60007o`000?l0o`0B00006`002FI[<6/`Jb/aXP02<@0:
HH2=P7f=4gdCO@:R00=nHS400V800c5n<@02OP03<F8a009R00<aOS400Wh00c5n<@02<0079S0V9S0V
<0029P03_S4b00Ha1:802Y6RXW;=L/eVcVH2cP0>3bH`9S7><JXaZS7e<OD3<@07ZW9b<G8acP02c@03
cW8?00;>0Pl00lh`<003<@;>00LacS7e4oDC008a00<C<C400S401LhacS7>00<V0S40104V4bH2<P03
<BHa00:o00IF<C4a0C4?0003o`0000<000Oo0000o`3o01/000UVJc1[<6/[<J800S402V60SH1mSA=m
4gd2XP03OV8a009R00<aOS400Wh00c5R<@02HP03<Gha009n00<aOS400S001bH`9RH`9S000RH00kha
<P06<@BR00ZAXZ9bcG;=I/iV0/h03PlV<2HacS6Z<JXamC7e0c401jYbLS5b<Lh00/d00lib3`02cP8?
00?><3000c42cP07<LhamA?e4`02<@034c4a008a00G><LhacP039P8a00@19Q<V0S800c4V<@02_`06
ES4a<@4a3`000ol000030007o`000?l0o`0B00007@002@m[cR^R<G8aLP02XP08SH2RXS6R<J84<@0;
P:8aP360OC5m<ED00S400bXa:P02<@0<<RHa4RHB9Q9F:a<[0Q<03C75<LEQ<F4aHI4acS400X003Lj0
L/ib3lh?cW8VcRH00/h00bI@<@02D00U<A<a4hg>Z/jZ<LhacS5b3c0?<<iVcVK>J`HB1Q8a5S7e<ODa
m@09<@074aHa<AHV:`02AP03:dH[00;e00AVmB/C0UH00a=69P02AP039VH000d000?o00000`001ol0
003o0?l07@002@m[cR^R<G8aLP02XP08SH2RXS6R<J84<@0;P:8aP360OC5m<ED00S400bXa:P02<@0<
<RHa4RHB9Q9F:a<[0Q<03C75<LEQ<F4aHI4acS400X003Lj0L/ib3lh?cW8VcRH00/h00bI@<@02D00U
<A<a4hg>Z/jZ<LhacS5b3c0?<<iVcVK>J`HB1Q8a5S7e<ODam@09<@074aHa<AHV:`02AP03:dH[00;e
00AVmB/C0UH00a=69P02AP039VH000d000?o00000`001ol0003o0?l04P0001h000=[cV/01j8028f0
SJ9QSX2>0Wd0264aXZ8aP7j00Wh00gen<@02HP0=<GhamGhacS7><19FAP02EP039S0V008600O5<LG5
<Gha009n13401<fAcI42c@?>01Ybc/k><<haZS6Z<JXamC7e1/jZcZ[><G;>LP;>00S=cW;>I/iVcP86
018B1Q86mC7e<ODamC7eYC6U<JD2<@074lha<Lha:`02AP03:c6F00;e0VH03;mF_kmFJc56IRIV9Pd0
0ol200;o0`000ol0o`0N0003Jli[00NR00R=P8fRHHj0SP9m00QQ<J:R<H1nP09n00=mOS400V803C5n
<OEn<LhacS0BETH00UH00bH`9P021P07aC75aC5n<@02OP@a00C=TLfA0/d3cP0JL/k>cS3><JXaZS6Z
<ODam@K>Z/jZcS5bcW82cP08cLibcVK>I/h21P0B4PHB1_DamC7e<ODamJDaYC6U0S401a?><C7><B/0
0TH00b/aUP02m@9V00boE[noEV/aAVHVIRH=00?o0P02o`<000?o0?l04P00020000][XZ:RHGfRHHf0
S@02H@07cX1mP7daO@02<@044c5n<@9n00<aOS400V80235nmOGU<Lha0/h01dH`ATH`AS000S40230a
<S4b4oDC0_D4<@05cW8[LR/017801V]bLV/`5P<a00FZ<JZZm@03<@FZ00S>3b/?:`m[3`9[00<?cQ80
1c403A<a4c7e4oDC<LhbcS800lh00aK><@02cP049P4a<@>F0101<P6F0EJo0HH1QP4F0AH13`001Ol0
003o00@00_lP000;Jj:RXV5mXV6=P8d00V401lj0OH1m<Gd00S4011<aOS42OP03<Gha009R00PaO_Ge
iC7><@;>00M6<4I6<4H`008a00P`<C8a<Q?e4`;e13401Lib:g8[00Ab00I[LW9[<1H3<@05ZS6ZZ_D0
0c45ZP08cPl[3b/?J`l2J`033lhB00La00dC<A<amA?e4c7></hb00?>00<FcS400/h012H1<C43UP0@
0C81UP5F_`660HH15P4F0@l000Go0000o`0400;o4P00020000DacC6R<@02XP08OGj0SJ:0XS42SP08
<F4aHJ8aXS42P008<GdaOC7>:lh2m@03c_DV008a00BFcUHa0UH00lh6<@021P07aC75<OEn<@02OP03
<Lha00?>00<[cR/00/h024K>A/haLS4`0S402c0aD50aSPJ>1/jZ00?>00AVc/k>0XH00g;>LP02cP03
<@Ha008600<B1Q800_D03C7e<ODamAHaYC6U<JD00S400a<a<@02EP0H<2]6:iH1UP5VUVJFIUI[:f/[
9VHVIRIV3P000ol0000X0005<LdaXS400Z8027enP8fRP:8a0Xh0235Q<F6R<J8a0X00235m<GdacR_>
0_D00lke9P02<@04U/iF<@9F00?>1S400PH01lDaaC7eOS400Wh00c7><@03cP03:lh[00;>00Q6cTK>
<G8a<08a00/`<E1@<Hh6SPK>ZP03cP04I/k>cP:600=bcW800/h00c46<@021P034PHB00;e00damC7e
<ODF<JDaYC6U008a00<C<C400UH0630[AR^F0IH1IYIVUVIFJb][:bIV9VHVIPh000?o00006P000240
00F=/7bRO@02H@03XX2=009Q00O>P7f0OC5m008a00@C<Gha0Wh00c5bLP02LP0<:g;emNGecS7>3hH?
0TH00lhVcP02<@03<34b00<a00Se4oGe4c7><@;>00P[LR]b<G8aLP8a00?><AH00S401AJZ<J[500Da
00>ZcRH00/h00bIV3`02cP8?1:X0118a<A83<@05OQ<a4c400Q<03C7><LhbcS;></hF3bH00/h00bK>
<@04UP040IH1UP8100^60HH13fHF0AH1J`0?0003o`0002P000F=/7bRO@02H@03XX2=009Q00O>P7f0
OC5m008a00@C<Gha0Wh00c5bLP02LP0<:g;emNGecS7>3hH?0TH00lhVcP02<@03<34b00<a00Se4oGe
4c7><@;>00P[LR]b<G8aLP8a00?><AH00S401AJZ<J[500Da00>ZcRH00/h00bIV3`02cP8?1:X0118a
<A83<@05OQ<a4c400Q<03C7><LhbcS;></hF3bH00/h00bK><@04UP040IH1UP8100^60HH13fHF0AH1
J`0?0003o`0001T0000Q000><LePXV2ROHbRcZ:0XX02SP09<F4aHJ8acW;>009b00=[cV/00/h022_>
:oG>mLha0YH02<jFc/iVcVHa0PH3<@;e0S42OP03<LhF00;>00@Fc/ib1Lh01G8aLS4`008a00P`<E1@
<E06SP8600@1I/k>0VH01j]VQ/ibcS400/h00c46<@021P034_Da00;e018amC7e5S4F<JDaYC6U<Lib
cW82EP03<0mV00:F00Ib3g9VUVH23`09:f/[U/hVIRIV009[3P03obT000hacF2RH:9mS:;>XX2RP0:>
00TaHC5QXS7>L/h00W800f_>J`02cP08:lh[mLkecS42UP08cYK>cVK>IS421P<a0_D2<@9n00<acQH0
0/h011K>cW85cP05LS5b<C000S40230aD50aD0J>0PH0105Vc/h2IP07ZfJ6cW;><@02cP03<@Ha0086
00<BmC400_D04S7e<ODF<AHaYC6U<JDacW;>LP9F00<`3fH00YH01W8?LVJFIP8?00T[Jb^FcRIV9VH0
0V/>00?o6P00028000ElHK1P?002XP07OH2RHFYQO@02P004LWebLP;>00Ebc/ibcP04LP03:g;o00?o
00Mb<HJFQPmb00G>00<6<@H00S42m@8a0oD00c7>cP02cP9[00]bc/h[cH3=<G8aLP05<@;50S4048h6
ETIF9/j[IZ/?L/ibcZX2cP04Z/ha1P8a00Oe<OGe<ODa008V00LacS7></hb00;>00<?L/h00[d05I5V
IRJFoU3nD?iV<<1/O9K>U/jFIP04J`03UP0000h000?o00009`001GaQ/60l00:R00MmP:9QJV5m00:0
00AbOG9b0/h01G;>cW;>00Ab00<[L_l00ol01g8aQYJ63g801Lh00`Ha1P02<@;e0S43m@03<Lk>00;>
0V/02g;>cR_=P<daLS5b00Da0/D2<@0@SPIFAUHVcZ]VZ`mbcW;>ZP;>00BZcS460S401oDamODamC40
0RH01c7><LhbcS800/h00`mbcP02_@0ETFIV9YKnD?i@oVH``6alU/jFcYIV00A[00>F00003P000ol0
000G00008`001j8lO;0lXV400X001::=XXd2LP06<G8aLPl10Pl03VK>L/j0cLj0cX3=P<f00Z803Wha
TJ8McRI[LS4F<AHC0S400a<am@03<@06cS5[<F/a0V/02OD?mC6=HLeQc@05<@;500/aaC56<4H`AP5V
3`04J`03:f/[00BZ00HamA?eOS42OP03<A<V008V00<acS400fH02c7>oonA1/h6cC4V008a00@?APm6
0f/01VJRXS`?EP;>00=F0F/00`400iH1000>0003o`0002L000NR?7b`?:9Q00:000BRSJ:=0W801S5b
<G8?0@8?00iVcW;>P<g>P<j0cH3=P0:R00in<I6R7LhVJg8a5S4F4`8a00<C<OD00c401/haJc5[<@9[
00We3oDaSF7=HLd01C42a@0;<LDaAS16<4H1IPl016/00b][:`04ZP06<ODCmGha0Wh00c4C9P029P03
<Lha00=V00/ac_ooT@K>1/da9P02<@043dH?AP=[00IVXZ8l3eH2cP03EP5[00<100>F0@003P000ol0
000F00008`001F5lH:9l009m00_>XZ9Z<FYbcW;>T@030@033c4a00:000K>SHdaSC42S@03<Hda009m
00<aOC400j8020o>3`Ha1S460_D00c7e<@02m@03<OG>009F00P`ES2FcR_>:`;=00>0<H001C401E0a
D341009F00<1EV/00Z/43`04cW;>LP;>0S401S8a<C;e<@;e00<[<B/00S402B/Fc/h?o`nAQ@06<@08
9S4V<@I@cU02IP03<04100;=00dlO<k>3liV:iJVIZH100d000?o0?l0:0001F5lH:9l009m00_>XZ9Z
<FYbcW;>T@030@033c4a00:000K>SHdaSC42S@03<Hda009m00<aOC400j8020o>3`Ha1S460_D00c7e
<@02m@03<OG>009F00P`ES2FcR_>:`;=00>0<H001C401E0aD341009F00<1EV/00Z/43`04cW;>LP;>
0S401S8a<C;e<@;e00<[<B/00S402B/Fc/h?o`nAQ@06<@089S4V<@I@cU02IP03<04100;=00dlO<k>
3liV:iJVIZH100d000?o0?l05`0002@000@lX[0l0V405J:0HHfRSJ9b3oib0C1F<5JR<F4aH@02c@07
P<j0cBEn9@03OP0<<GhaXY6RJg9[5S4F0c400a<a<@04<@9[00laJc5[U_D?m@oeSC5QcF401342a@06
<BHaAS1610403>I[Jb_=c/g>cGhaOP;e00DCmGhaOP035P@V00G?eW;m1P04<@07cPK>1Wha9P02<@03
<S4?00=[00<1IP400[d01Z8lO<h?cP8100>F0IH00P400fH0000<0003o`0002L000@lX[0l0V405J:0
HHfRSJ9b3oib0C1F<5JR<F4aH@02c@07P<j0cBEn9@03OP0<<GhaXY6RJg9[5S4F0c400a<a<@04<@9[
00laJc5[U_D?m@oeSC5QcF401342a@06<BHaAS1610403>I[Jb_=c/g>cGhaOP;e00DCmGhaOP035P@V
00G?eW;m1P04<@07cPK>1Wha9P02<@03<S4?00=[00<1IP400[d01Z8lO<h?cP8100>F0IH00P400fH0
000<0003o`0001D0000T0004O65PO0:R00MmXZ;><FYb008?0P401B/1<0l`008a18003Wj=<F9^<Fha
KWdaOC5m0S402<hl3lha1S460_D00a;e4P02m@03<OFo009F00``EP6FZg;>LWfRP342P0Ha00?>A/h0
0UH01f^[Jj/1cPl00W800lim<@02O@Ha00Pb<C7e<B/a:`8a00OV0NIb<C0a00:51S400bHa9P021P04
OfH`IP@100XacC5lHGabcW8[0ZH01VJ[0J/1J``000?o00009`0017aQH7`2XP07OJ:RcS5ZLP023`81
00D[0C0?<002<@B000inSC5RKS5^<Fim<GdaO@8a00S>?0o><@Ha1P;e00<BmA800_D00c7e_`02EP0<
<5H1UZ]bcW9mXX0a0X06<@03cTK>009F00M[Zf^[0Lh?009b00?>OC400Wd6<@08<S4amC4[<B/2<@07
iP7VLS4`<@02Q@Ha00<V<BH00PH017mV<6H40@0:<LdaO65lL/ib:`:V00IVZ`6[0F/<0003o`0001D0
000U0005XW`l?6400Z802LdacC5QoXH1iP02AP080J:AXXeQP642_@0BHVYROS5n<GimOWen<X3=P<f<
0W`020HaD37e4_DB0_D01[mF_kmFJ`:F0Z/01f^[LW:R`J800/d4<@0LcTK>A/i6Z`6[0NIVcVK>OC5m
cGg=OS5n<ODam@@a00`[<BHV0NKoL_da1S42Q@04<Gh6<P9n00<b<C400PH06[lV_f]V0FJF`;f=cJ9l
cC7=<IJ[0J/1J`5[0oh900?o:0001J9l?3aQ00:R00W=<LdaHOj60NH00TH0206RTJ:=HH1Q0[d04V9Z
HWhaOS5nOGimOS:0cH3=S09l00P6<E0amA;e4P;e00JoE[noEV/2UP:[00M[Zg9bX/6R00;=13407<i6
cTK>AZ/1Z`7VI/iVcWdaOLemcGhaOS7e<OD4<@0<:c4V9P7Vog;m<@Ha0XD0135n1S82OP03<S4a0086
01Zo9[m[IP5VU/2mSLfRO<dacC6FZ`6[0F/1J`?n2@03oaD0000V009l00MQO::RHC5Q00:60181iTH?
cPo>3hfRSF4aHGfmHC42H@039GhU00=n00dbOS:0cH3=cXbRcS7>00La00QF<EIFJ`6F3`9F0Pl00c7=
c@02O005`J9QcS400/h012Ha9S420@0;3nH10FH[LR^RcJ800/d02Xg=<GhamA<a9S455P03i/o>00;>
00L6<@Ha1S4C009n00<bOWh00S800c4b<P04_`05IYH1IXH01Z84LP03IP5V00<100D20@7n9P0:0003
o`0002L00W`01f5lXZ9Q<F400XH04P7VAPo>3lh?SJ:=HC5QOKeQ<@9Q00<UORD00gh03C9n<X3=P<g>
S:;><Lh01c4025HaEUI[0IH?0UH23`03<Lg=009l00G1XV7><@02cP049S4V<@8100/?iP41IR]b:j;=
XP02c@0:SLdaOS7e4c4V<@DF00?Vclh00/h01`Ha1S46<A<00Wh00c9nOP02<P03<C8b00Bo00EVUP5V
QP06XPAb00=V0FH00`401@810OhV00X000?o00004`0002H000Yl?3al?<fR<@o>0Pl02]JVeYJ60HJA
/344P008OX1ZHVXaKS42KP04<GlaO`<a010F<C5l`35@<ODBmA;eE[mF0[l20@07Z`:[Z`5V0@02c@03
P8b000;=00Qm<@laA/i60@:[00<?0Oh01/h0135m<Gd2P0Xa018[<B/19PlV3c0a<34`OZYnZS82<@03
<PIo008600No9[no0f/?009V00Pa`370XWaQcP9b00S>0@7?J`7n0@;>00<?cP002@000ol0000300Co
0P02oa/000Yl?3al?<fR<@o>0Pl02]JVeYJ60HJA/344P008OX1ZHVXaKS42KP04<GlaO`<a010F<C5l
`35@<ODBmA;eE[mF0[l20@07Z`:[Z`5V0@02c@03P8b000;=00Qm<@laA/i60@:[00<?0Oh01/h0135m
<Gd2P0Xa018[<B/19PlV3c0a<34`OZYnZS82<@03<PIo008600No9[no0f/?009V00Pa`370XWaQcP9b
00S>0@7?J`7n0@;>00<?cP002@000ol0000300Co0P02o`L0000V008l00MQO65lcS7>00:F01;F0MH1
QPo>3lj=O:8aHGfmOC42H@039GhU00=n00LbOS9n<Lha00;>00@aS37>1C430004<EHaJ`@100d?cPo>
<LdacGbRHJ8a00;>0S40104?0NH30@05IPl[LR/00W803Z;=X/f=<HdaSBHa9S4V0aH2iPC>00@6<@Ha
0Wh011=n4c82OP04<C8a<PFo00@2khIV0XH3XP03cH3=00=b00<[3fH00P401oi@oPlV:g802P02o`D0
00?o0?l00P000ol0o`0J008l00MQO65lcS7>00:F01;F0MH1QPo>3lj=O:8aHGfmOC42H@039GhU00=n
00LbOS9n<Lha00;>00@aS37>1C401eHaES5F<F/010403@o>3lhacC7=O:9QXS400/h2<@040@l1iP<1
00EV3b]b:`02LP0>X/fRcHdaSC6=9S4V<BH35P;V1<h010Ha1S42OP044ghC<P9n00@a<S4b1Kl010;_
QVH2QP>R00?=P<d00g800b/?IP020@07oU3n3bH[LP0:00;o1@000ol0o`020003o`3o00H0000W0003
?7al008l00_=QPn6eZKFYV^FIP03cP03XS`a00>0019nP6YRJS5^<FhaZWlaOc4b<AH2<@04IP4aD08a
00<Bm@0010007[l10@:[0Z]V0FH1_C6m<G:0X/7=3g8?LPmbZ`7n3`;>00=Vc/h00/h0136=P7d2P004
cS6RXPHa00@[0Lm60Pl00bH?9P02<@07JS6ZZWjZ<P02<@07OS9o1RJo9P02_`0=0c9AIW;>cH3=`::>
XP02LP09cV/?Je015PmV00;>00<>cP002P000ol000020003o`00008000?o0?l06`000calO002?00;
cHH?Q]JVeZI[UVH00lh00j8l<@03P00BOX1ZHVXaKS5^<JYo<Gla<S4F0S4016H1<E02<@084_G>cUJo
E[l20@0K0Z/2ZfH1IP6m<KdaLX2R`Ld?LPmb3g:[0Oh?00;>00=Vc/h00/h0136=P7d2P004cS6RXPHa
00@[0Lm60Pl00bH?9P02<@07JS6ZZWjZ<P02<@07OS9o1RJo9P02_`0=0c9AIW;>cH3=`::>XP02LP09
cV/?Je015PmV00;>00<>cP002P000ol000020003o`00008000?o0?l01P0002P00S`01Xfm_HfmUP;F
0P42QP0=<F/aLXelP35QOKem<@02H@039GhU009n00hC<WhbORK><Li[<F/acP<a1`000f/10@020@04
UP7>9P;>00C=SLf=0Z800l6R`@04cP053f/?Jll00VH00`o><@04<@0;SLg=SLf=<HdV<BH00S403AKV
i^HaOQ>=4hf>OXh00Wh02A=n4c9n<S4b<@04_`050[n^kjh00_D05b_ecLk=SLf=cFH`IS01oVH?IPmb
:g8[00/000?o00000`001ol0003o0?l07002?006SKfmSKfF0]H20@:600daJc5bSGb0<F5m_Gda009Q
00<UORD00Wh03Q<bOS9n9/hacV/aJc7>0c40231FES1F<@5[104019H1cRH2cP04cHg=S@:R00?1X/40
1<h01@m[3f_?009V00<?cS4013402hg=cHg=SC6=9S4V008a00dFi^KV<GhCSA>=SWj>009n00TCOQ<b
OS8a<S401;l01@:o[^n^00;e01L[mLg>cHg=SLeV<6H`0OiV3fH?LR]b:`0;0003o`0000<000Oo0000
o`3o00H0000Y000KS<;=cH3>L/jVQYJ6UVI[IZ;`O;20HH2mP6YR009Z00=n<Gh00ZX01C9n<S4b008a
0V/00fI[IP03c@03cP0000D000A[Z`:[0iH02LhVc/ha_Lfmc@02XP09cJ:RTJ8[LV/?00=V00Ce9_DV
0Xd00c6=S@02c@03X/eQ00:R00>=<C400ZH01Po>Y/jROPB=00R>OXinSZYnZP9n00HbOS9n1RH4_`07
[S81o_G>m@05c@0ASLg=<6_nD9E[D<ibXY6RTC402P02o`8000Co003o0P000ol0o`0M000KS<;=cH3>
L/jVQYJ6UVI[IZ;`O;20HH2mP6YR009Z00=n<Gh00ZX01C9n<S4b008a0V/00fI[IP03c@0<cUK>cV/?
Z`5[Z`:[0iH02LhVc/ha_Lfmc@02XP09cJ:RTJ8[LV/?00=V00Ce9_DV0Xd00c6=S@02c@03X/eQ00:R
00>=<C400ZH01Po>Y/jROPB=00R>OXinSZYnZP9n00HbOS9n1RH4_`07[S81o_G>m@05c@0ASLg=<6_n
D9E[D<ibXY6RTC402P02o`8000Co003o0P000ol0o`060000:`001L:<L/ib009V00<[UP400VH00`56
<002XP08/69RP7j0JV82JP03KZXb00:Z00=o<Gl00S800b^o0@02IP060II6cJ9l1`002@nFAYH1UTHa
9P02cP@a01R0<H0aL/g>L/ib3fH?I/ke9_DVmHdaSC42S@04X/fR<@;=00`a3lh?9PlV3j8aXVD2S@08
IC5Z<GjZOZX2OP06<WhbO[lV0kl02C81oP5bOC5mcP02c@04P:8aXP;>00=V3iD00`l02<i@c/jRcZ;>
2`000ol00002o`<00_lP0005`XabcW800VH00b^F0@02IP030DH`00:R00R`HV:0OX1ZHP9Z00=^ZS80
0ZX00glaO`02<P03:kl1009V00`1UTK=XWaFcUJ[3j/23`08UTJF0II6<BH2cP@a01R0<H0aL/g>L/ib
3fH?I/ke9_DVmHdaSC42S@04X/fR<@;=00`a3lh?9PlV3j8aXVD2S@08IC5Z<GjZOZX2OP06<WhbO[lV
0kl02C81oP5bOC5mcP02c@04P:8aXP;>00=V3iD00`l02<i@c/jRcZ;>2`000ol00002o`<00_l70000
:`001HfmO2_?009b00_?<5I[<DH`A[caP002O004HKem_@9Q00<aOQ<00Wh01Q=nOS8a9P8a00=6Jc40
0`401;eU_K`5000@0FH`3c2FAS16<<hV<BJ=<@:=00[=SLf=<@lacVK?0VH01S5V<LhacP<a00N0SKf=
cF7=009b00S>LZI6Y/jVcP9n00<aSA<00Xd03Gj>OXhCOQ=n<C8a<S401;l01@8cI/h[00;>00B=<Hda
0Z8012]b:g840@05Jg9[TC400Y40178aLS4e0005SKel:ll00W802ll`EV/aAS16_?60009l00AQ_Gfm
0V400c5n4`02OP064gin<S4V0S400dI[<@030@05_FFm_5H00V/04PmV0FH`3c2FAS16<<hV<BJ=<@:=
00[=SLf=<@lacVK?0VH01S5V<LhacP<a00N0SKf=cF7=009b00S>LZI6Y/jVcP9n00<aSA<00Xd03Gj>
OXhCOQ=n<C8a<S401;l01@8cI/h[00;>00B=<Hda0Z8012]b:g840@05Jg9[TC400Y40178aLS4L0000
:`001Gc=_Lfm009V15H024H`AS2AX[0l0V8017j0OV82JP03<ZXb00:Z00<b<B/00S803@6o0KnFAYI6
IXdaSG`00`023`:F00=69S400TH00c56<002<@03<34a008a00N0<H20cW8V009b011VcR_>mBKe9_F>
<HhaS/da0/d03c6RcFH1:iHV3bH?XS6R<@02S@08IC5Z<GjZOZX2OP06<WhbO[lV0kl016H?LS42LP03
<Gda009m00daOLh[cPmVD@6[cW;>00:R00?>X/h00Wd40003IP0002h000ElcKg=_@02IPAF00Q6<4H`
TJ:`?09R00AnP7iR0VX00c:Z<P02ZP03<S4[008b00`1_`6oUTJFAVJ=<Hd2O004Z`l?3`:F00=69S40
0TH00c56<002<@03<34a008a00N0<H20cW8V009b011VcR_>mBKe9_F><HhaS/da0/d03c6RcFH1:iHV
3bH?XS6R<@02S@08IC5Z<GjZOZX2OP06<WhbO[lV0kl016H?LS42LP03<Gda009m00daOLh[cPmVD@6[
cW;>00:R00?>X/h00Wd40003IP0001D0000/000AO8fmSKd`ES1F<C16<4IF<8000W`02GeUO[eQOQ=n
4`02OP034gin008a00DVAS56<@030@0;Y/k>_FFR?;fR_J800S002li6cTH`ARHa9S4V008a0Xd01c6=
cJG?c/l00/h026HaIS5V<@Ha0PH0180aP342_@03SKg=009V00<?AP400VH02<jVcZIn<GhC0Xd03Gj>
OXhCOQ=n<C8a<]D00[l01`:o<T=V3b/00/h018daSC42XP03<J8[008100QAJ`m[LV]bJ`:A0S401G8?
3`m@008100=V0000;P004Gb=_Hfm<5H`ES4`AS16ES20009l00UmIGjmHGhCOQ<00Wh00a=nOP02<@05
9THaAS400`402jK>c[eUXSbmX[fR008`00_>A/i6<4HV<BHa9P02<@:=00LaSLfUclk?00;>00QV<FHa
IS46<@8600B0<H0a0[d00hfmc@02IP033dH1009V00S>Y/jVOS5n4`:=00enSWj>4ghCOS4b<C;E00:o
00L2_c93IPl[00;>00B=<Hda0Z800c6R:`020@08DF/?Jg9[LV/2T@8a00Eb3`l?D0020@03IP0001@0
000/0005?:8aXW8015H2IP07<DIFETK`O002HP03OGim009n00AZOZYn0ZX00ghb<@02<P08AS56<P56
IZH2cP03YXfm00:R0ld01Li6cdK?009600S>:lhV<BHai@8a0/h01JG>c/hV00;>00=FcVH00/h00c46
<@021P07P8j0S/g>c@03cP0=UR]V0JIVYZ:=XXjRSP03S@0<OXinSZYnZWjZ<Whb0]D3_`05<Wf=IS40
0X001S5mP7f0<@?>00GVD@6[0@02cP07<G8aXS6R<@03LP060@mVcVK>;`001CbR<J9b00AF0VH01c56
EUI6l7`00V800genO@02OP04JWjZOP:Z00=n<S400S8024HaAS81AVJV0/h00jJ=_@02XP?=00G>A/m6
c`02AP08cR_>9S4V<ND2<@;>00FUc/k>9P02cP03E/iV00;>00<a1S400PH01h2>P8k=c/d00lh03IH[
IP6VIZJRSJ:>XXh00hd037j>OXjZOZYnZS9n<P;E0kl01C9mSFHa00:000HaOH1mP343cP05iU41Z`40
0/h01c5b<J8aXS400g801P4?I/iVcQD0000^0006?::RcUI60VH014IVAS42AP07ccaRHWeoO@02OP04
JWjZ<P:Z00JU<R/b_`42000><P9@0U1V<G:ROXfRP342XP089/lVclh[cR/2cP07<Kk>_/hacP02<@;>
00Ha9/k>E/h3:`049R/a4P8a00R><Hk>9PlV3`:F00=V0@400VH05c0aSHem<GdaSFDaJS5ZZQ>Z4jXb
OS:Z00:o0P<01IG><Gda00:=00<aSC400Xd022H?9Po^0F^[0/h03fH1cP6RcZ9b3g8?LPo>3`0c0006
?::RcUI60VH014IVAS42AP07ccaRHWeoO@02OP04JWjZ<P:Z01JU<R/b_`6o0C82D09@IS5bXWj=XX0a
0Z8022K?9/o>:lh[0/h01c6nc[k><Lh00S42cP06<BK>cUK>0b/012H[<A82<@08SS6>cRH?9Pl2UP03
IP41009V01L`<Hf=OC5m<HeU<FXaJZXCZQ>Z<WhbZP02_`8300FEcS5m<@02S@03<Hda00:=00PV3bH?
kP5[Z`;>00mV0Lh1X/jRLPmb3g8?cPl05`0002l000IlLW8aIS42IP0<Jc5FES5[;7amIGiU0Wh00a=n
4`02OP034c4b00<a00Q60000_`:o0P8a00?><C400V403Z8CcLe6cTHV<2Ha9S4V1ND00lhacP02Y@04
<Lh`9P8`00O><Lk><Lha00860S400iFZZP03cP03QYJF00810ZH026JVXS6RSX2>0X0028dCSWj>4ghb
0Wh00c8a<P02e@080[mBYC6=<Hd2P005cX20<H000lh01NIA3hH?00;>00@?cW8?0W801lh>oP7?I/l0
=P001WabLS5V<@9V00a[<EIF<F//O7eUOVD2OP034ghC009n00<C<C800c400dHaAP02_`030[l2008a
00?><C400V403Z8CcLe6cTHV<2Ha9S4V1ND00lhacP02Y@04<Lh`9P8`00O><Lk><Lha00860S400iFZ
ZP03cP03QYJF00810ZH026JVXS6RSX2>0X0028dCSWj>4ghb0Wh00c8a<P02e@080[mBYC6=<Hd2P005
cX20<H000lh01NIA3hH?00;>00@?cW8?0W801lh>oP7?I/l06@0002l000Dlc/i@cP02IP0=AS16<<m6
cdJ`HWeoO@02OP0;JWjZ<ZXbYC8[<[l01@003502iW8aLS5nXX3><@:R00<acbH00Xh00bK>:`02cP08
I[k>_/hacS42cP039PlV00;>00=VEVH00R/02BH[9Q8acWk>OP02cP063iH1UP5V0P42IP04<6J=S@8a
015m<Hf0SFXaJZXCZQ>Z<WjoZP02_`070a2EcS5m<@02S@03<Hda00:=00Ta3`4?JiH`U/h00VH02PmV
LW8>T@l>0@lh0005?<k>D<h00VH03DH`AS3?A/m6/69mOgd00Wh03FYnZS:Z<ZDb:c:o0Kl00S803@9@
0^Ib<G8aOZ:0cS400Z800c7?9P02SP039/h[00;>00QV_/jncS7><@;>00<V3bH00/h00fIFIP02:`09
9R/V4S7>O/in00;>00H?UP6F0FH20@9V00@`IXf=0S404GdaSH2=JS5ZZQ>Z4jXbO[nZ00:o00L349G>
<Gda00:=00<aSC400Xd02C4?0@m[US2FcP02IP0:3fIbLPjA3`h13a/0000`0009O78aLS5[<F/a009[
00PaJc60OFEnI@9n00<COQ<00Wh01S8a<S56<@D000H2i^KV<Lh2<@9Q00R=cLdacRH`9P8`0bH2cPCU
00C><G8[1/h00`o>3`02cP03<Li[00BZ00REZZZEQYJ6UP810VH02JIV3`llO::0SP03P007OXinOS9n
<P02OP03<S4b00;E00l2_h0aP8f0SC60cX3><H000R/20@0=QPn63hK>3lha3g81LP03cSX000UlLS5b
<F/aJc400V/0235[<H1mIGiU0Wh00a=n4`02OP0<<S4b<DHaAS6o0Kl20nH0137><C42H@08SLg=<LhV
<2H2<0<V0/h4i@04cS5b:`K>00<?cPl00/h00c7>J`04ZP08UJZZUHJFQYH20@9V00VVIPl??7bRP8h0
0h001gj>OWhbOS800Wh00c8a<P02e@0?0[n0<H2=P8daP<j0cS60008[0P403HH?QPn6cPo><@mb0G80
0lhL0000<0002Cc><Li@JdI[AP02J`08A/m6lV9mOWd2OP0;JWjZOZXbYC:UAS401@002>K>i^J=cHeb
0Z800hg=S@03<@05cXj>cVH01/h00kk>cP05cP03IS1V009V00S>I/iVcW;>LP;>00>ZcZX00/h01C3>
QYH100=V00E[cU3>D002O007<Hj0SX2=JP02OP09JWjZOZXbO[oE00:o00=B1S400X002<f=cLf=cHda
0/h20@0?cYJFQYJ6US5@LY5b3`h?03`000TlcS7>D6]6JdH00V/024K?A_9ROGim0Wh04VYnZWjZ<ZDb
YDHaA[lb[_oVcP;V00B=cHeb0Z800hg=S@03<@05cXj>cVH01/h00kk>cP05cP03IS1V009V00S>I/iV
cW;>LP;>00>ZcZX00/h01C3>QYH100=V00E[cU3>D002O007<Hj0SX2=JP02OP09JWjZOZXbO[oE00:o
00=B1S400X002<f=cLf=cHda0/h20@0?cYJFQYJ6US5@LY5b3`h?01h0000c0004cU1@APE[00??A/l0
0V803GmmOgiZOVXbZS:U<ZD00[l500<?00Dac/j0cP02XP04OX3>P0@a00XVIPmV3fH?:`mb0/h00g;>
cP02LP07cPo>cPmF3`02LP04cW;>LP;>00<acWh00VH0131VYZH30@0@Jj/?EPmlcW`lOC6=P8f0<@9Z
00<CZQ<00jX01knZ_kla1/h00S403LdacLdacC7=cP7>U/h00YH01/jF:e0?:dD000C>D5161F/00lm6
c`02HP0=OgeoOVYnJS:Z<ZDbY@02_`050@8bkP000`l01C7>cX3>00:R00AnP<j013402RIV3fH?IPl[
3g82cP03L/k>009b00O>3lk>3eH?009b00C>L/ib0/h00c7>OP02IP04<6JVYP<1011[Z`mF3gc>O3am
<Hf0SH0a0VX00a>Z4`03ZP07_jZo_c46cP02<@0=cC7=cC7=<Lg>0LjFcP02UP06cYH[D0l[900003@0
00Da3g9[<@02J`:F00HaJo5mOVD2OP044ghCOP8b00Da<S5[<@03000DXS7=c/eb<Lf=cHeQ<Lf=cLha
cR/2cP0FI/h?oS0?<0l[TG:ALPo?3c1V<78?LP;>00@?:f/[0ZX00b]b9P02cP069P6V0OIV1@43QP08
O3b>P8j0OX02OP03HGhb009n00TbeC;E<P8acS400X000c6=P002S@08<Hg>cPnF3iH2cP04QPl1odP0
00Da3g9[<@02J`:F00HaJo5mOVD2OP044ghCOP8b01`a<S5[<DH1[Z8acLk=LS7=SLf=HC7=SLg><Lh[
0/h05VK>3oh`3c0?:i5bTG8?c`l`IS1b3g82cP043b][:`:Z00<[LRH00/h01RH1YP7fIPD10hH027`l
SX2>P7j00Wh00f5n<P02OP09<]DbeC82<Lha00:000<aSH000Xd0236=c/h?UPnF0/h018H?0OlV0000
=@000g;>LP03J`0BUPnFccaROgeoOVYnJS:U<ZDb0kl04S82kZ8aXX2RP8g>P<j0XX0aP08a1<h016H?
3`H2o`03<G8a009b00<aLW800/d2LP06cW8VcRK=10001W;=cP7>0@9V1JH02P6VJeH?0@l1UW`2?006
<Hf0SH0a0VX00a>Z4`03ZP0A_jZo_c46<7;>L/ebcC7=3ld00VH020jF3hH?U_mbBP000g;>LP03J`0B
UPnFccaROgeoOVYnJS:U<ZDb0kl04S82kZ8aXX2RP8g>P<j0XX0aP08a1<h016H?3`H2o`03<G8a009b
00<aLW800/d2LP0@cW8VcRK=L/i6`G;=cP7>0@9V1JH02P6VJeH?0@l1UW`2?006<Hf0SH0a0VX00a>Z
4`03ZP0A_jZo_c46<7;>L/ebcC7=3ld00VH020jF3hH?U_mb9`0003D000D?LPmbJ`03UP063eIlOGiU
0Wh011=n4c42<P04<C9[J`8300Hb[Z8aX/h2c@0M9Kf=cHeQ<F6RcG8[LR]bcPonoc5bcC7=<J;>XS40
0W801S5b3lh?cP8?1@02LP06:g8[LP6V0P401_H13`6[0@>600X?EUHlO82>P7j00Wh00f5n<P02OP09
4oDbeKo><Lh?00;>00=bc/h00S401Lh?c/h?00;>00B6cXKmC0001@mb3g9[00>F00H?EWamOVD2OP04
4ghC<@8b00@a<V][0P<01S:^XS6RcP;=01dU_Hg=SF4aHJ;=LR]b:g;>3oko<G;=<LdaX/jR<@02LP06
<G8?cPo>0Pl2LP0;3g9lO78[LR]b0JH00P401_H13`6[0@>600X?EUHlO82>P7j00Wh00f5n<P02OP09
4oDbeKo><Lh?00;>00=bc/h00S401Lh?c/h?00;>00B6cXKm:@0003P000]bcG8?cPo>l69nO@02OP03
JWin00:U00@bYC9[0kl01X2RXV6RH@;=00>=_Hd00[d01::0cH02c@C>00@?08K>0W82<@;=00JR<J8a
X/h2<@;>00@VcVK>1P001/fRc/eb3`:V00KfYZJ[YZ/2YP040IIFUP9[0W`013b0SH02OP0>JWjZOZXC
mKoE_`H`cS02cP0?LVIbcLkec_G>I/iVJke@050000]bcG8?cPo>l69nO@02OP03JWin00:U00@bYC9[
0kl01X2RXV6RH@;=00>=_Hd00[d01::0cH02c@?>00Gn3e26cP02LP8a0/d01Z8aXS6RcP8a0/h02BK>
I/iVcTK>P002c@05X/k=LPl00ZH01_JVYZ^VZ`:V00@1UUJF0V/2O004?82=P09n00iZOZYnZQ?e_mFo
1S3><0;>00mbIW;=c_G>mLiVcVI[_E00:P0003h000iFl69oOGmnJWhbHZDbY@>o00<2kS400Xh3<@0>
9Hf0P8f0_HfmcLk=L/h50006QPn6cP7>0V46<@099S4VcTK>A/i600@000n0XX2<_HabcW;>LZH?YP40
0ZH00f^FEP02J`08<6Hl<H2=P8d2JP0?<JXCZS8a_jZoZeIV3g;>008a0W802C5bcW;>3c4?LP1H000>
E_1ROgeoOVYn<V:U<ZD3_`030^ha00:>0c406BF=P82=P;f=_Lg>cG;>3jK>QPn63hK>0Lh00V46<@0L
9S4VcTK>A/i@cU3>D<jRP8bmS7;>L/ibYPnV0@:V00=[UUH00V/0231V?360SH2=0VX03c6Z4jXb<KnZ
_j]FIPmbcP02<@9b00TaL/ibcPla3g80;00003l000C`lGiU0Wh011<aOS42<P08<@=[Jc;e4c42P00;
XV6R_BFRO::mP;d00X000ld0000500063c7>cX3>0X00237>OS5n9S4V0S401FHaIS5V00@000C=SLg=
0Z80194?<0l21P04Z`6FUP@10V/01fH`ISb0OX000Wh03V5n<Wke4oDbeKmFU/hV1?D2cP04:oD[m@8?
00=[_@00F@001?3aOVD2OP044c5n<@8b00Pa0f][<_DC<@:000^RHJ:m9J9lX[f0_@02P005c@l10@l0
0TH00lh?<@02cP0<P<j0P37>OS5n9S4V0S401FHaIS5V00@[00C=SLg=0Z80194?<0l21P04Z`6FUP@1
0V/01fH`ISb0OX000Wh03V5n<Wke4oDbeKmFU/hV1?D2cP04:oD[m@8?00=[_@00;00003l000cb?8j0
OghbHS9RYC84_`030S4a00:>1C402hdU<J9bcG;=L/d?00D000?><Lh00S401f0aXZ8aJS400VX02C4V
<BHaA/i6cP02IP0<D2H?9S6R<H3=o`K>0PH02VK>YP6VUV^[9Z/4IP05O7f=P8d00VX00c5Z4`02<P0D
<C83EXH?I/iVcS7><G8aL/i@cW9L000<lSb>P7mn<V8bHZDb1;l00`8a<@02SPDa00f=9C6RL/ebcG;=
3jJ[00;>00@VcS7>0S401f0aXZ8aJS400VX02C4V<BHaA/i6cP02IP08D2H?9S6R<H02c@0>1/h61VK>
YP6VUV^[9Z/4IP05O7f=P8d00VX00c5Z4`02<P0D<C83EXH?I/iVcS7><G8aL/i@cW8_0000?`002/ka
OX1nP7haOS42<P08J`=[0a?e4oD2P00<<F6R_BFmO:9l<Lha0/h00f]V000200043lk><@;>0120cX20
4h1n<GhV<BHF9VHa0fH00`7>cP02cP04SLf=c@?o00L63`IVcVJF00<100]60FH`IS1VO65mP002OP0?
HGiQO_DCmA>oI/hVcRK>00;e00P[3g9b3g8?oEd000[>lGj0OX1n<Gha0S8026/3J`<CmA?e0X00335Q
X[dU_GbRO37><@;>00I[IV]VcPl2cP05<Lk>P<h00X0031>0OS5n9S4V5RIV<@=V00<1c/h00/h018g=
SLd2H@08<@H?1VK>IYH30@0;AP5V<6H`IWaQOH000Wh03f5nHGke4oDC_fK>9/hVcP02m@08:`mbLPmb
3od`0000@0004_7`P8j0OV9nHZDbJkm[_c7e<@;>00Q[L/emcHf0S@:R0g802/i[Jf_><Lh?cPl3cP0:
H35PXS6ROVYn<@8V00@F9RK>0fH00iI[EP02cP04L/dac@Ko0VH028IVQZ/VZbI[16H02LhlOF6=P6Yn
JP02m@064oDC_liV1Lh00g;>_@02cP03_I4005l001;al82>P7iROV:U<V^oJklamC42cP08Jg;=OLf=
P8d2XP=b00[>Jf][cS7>3lh?0lh02V0aH:8aXWiZOS429P045RHVcP=V00>FJeH00/h02W;=<Lf0cH3=
1/h2IP08QVJ6ZbJ[9V/4IP09cSamHHf0JWiZ00;e00HCmA>ocVH5cP03L/jm00;>00>mT@00<@000400
00Xll82>P39R<V:U1;l01JDa3fH?009V00<?cPl01/d00li[3`02cP083c5V<FHVI/h2LP0><F0aH:8a
XS5ZeC7E<AH2<@03_fHa00:F00=[3g800/h00g8aH006o`04QS26<0:V00XV3f]@LU3>D<hl0bD01C65
XXDa008b00Xa0[n[IZ]V3iKoI`002Sc`P8j0<V8bHZD3_`060:Da3fH?0VH00`o>3`06c@03cV/?00;>
00P?<FHaIRIVcP9b00haH35PXS6R<F[E<MDa5P8a00>oIS400YH00f/?LP02cP04LS5PH0Da00B6<8H`
0ZH04RH?Je1bD<i@cSalOGamQJ:5<@8b00Xa0[n[IZ]V3iKo>@00044000o`P7j0OS5n<Gh3J`=[</h0
0Pl2cP8[00JA<I7P<Lh2P004LRK>9P;>018?cPo>LR]b:j8acZ;>P1>04c42<P03<BHF008V00<19P40
0UH30@9b00<[<Ld01_l03`mV3`7f3`7o3bK>9_h?0@049@@C0_D02Q?e<[mV<9H1U/iY000<l81nP7ha
OS5n0f/30P000lh?3`02cP8[00JA<I7P<Lh2P004LRK>9P;>018?cPo>LR]b:j8acZ;>P1>04c42<P03
<BHF008V00<19P400UH30@9b00<[<Ld00/d06<k=cW8?IPl1mPl1o`lVcRKn3`4lOF5mH@<C0_D02Q?e
<[mV<9H1U/hj0000@@002O20SXhbHS9RU@04_`:F00eFUPmVcPo>OE2RD7`l00;=00=b3g800XH04G9V
c/iVL/ibcS5bP<f0<H0a00;E01<aeC4F<FJoI[m[3fH?IW;>L/iP00Ko00XU<2GfoP5@aTJ60Pl00fH?
IP049@05XXFRQJ800S801c42_j/?J`l0J`002O20SXhbHS9RU@02_`@000eFUPmVcPo>OE2RD7`l00;=
00=b3g800XH04G9Vc/iVL/ibcS5bP<f0<H0a00;E018aeC4F<FJoI[m[3fH?IW;>L/h2H08a00g>:lk>
<:KfoP5@aTJ6008?00=V3lh00W`01gelXXFRQJ800S801c42_j/?J`l0?000044000g`P7j0OS5n<OFo
J`?o00;>00L?c/k><Lha00>R00>=XV400_l2LP043lk>0@?>00h?cW8[LS6R<LjRHC5Q<@8b00<a<QH0
0RH30@08olG>aLg2<Lh2<@03TOoo00;o1BD0107m3`42IP04Jlj6cPDU1A<01oDC_c:oUP40K@002o20
OX1n<GhamKm[00@000L?c/k><Lha00>R00F=XV6<O002LP043lk>0@?>00h?cW8[LS6R<LjRHC5Q<@8b
00<a<QH00RH30@08olG>aLg2<Lh2<@:A00LaLR]b<6H`008100?m3`400VH02V_>Q/iV3gaQOF444`07
mA>o<[nF0@0n0000@P00482>SWiROV;e_oFoLV_>LVH2cP04<LhacP:R00>0XS`01_l02Lh1c/h63lh1
LP05cP0:cF60HH3E<MEVYP9V00`1<C7eaOG5mKelcG`2c@03TLdU00HU00JFaTJ6JhH2J`03I/j600DU
00Z5XXFRmA>o<P4?K`002X2>SWiROV;e_oD40008LVK>cS7><Lh2XP06P:8l?7b<0/d00hK>0@02cP05
1Po>0G801Lh02/eQP660eC7EIZH2IP0<0C4amLGeaOFmO<el0/d03i7=L/iV<?h?oYK6AXI[QP02J`03
I/k>00:V00eQOF65XXFRmA>o<P4?03l000120006?8j><V8b0YD03P6EcPo>3bH?9/hVD35@0S400h2R
P006o`03c_oo008`00<?oP400Pl01BH?9Pla00:000PaP=Da<6H`IP8a00GeO_Dam@039P07cHg=?<70
cP079@:F00TaQV][IV^[_hH01BD028FRQJ8b0[l2L@001cb>SS9R<YD01P002@lV3bK>9U0aD002<@03
P::000BR00DacLh`3`02<0033oh1008?00DV3bH?<@02P008<H3E<C1V<6H2<@05mGke<OD00bH03/f=
cCc1`<ibcW8?cPmF0YH02C66Jf]VJj^oQP023`0;OGamQJ:5XS82_`80@@0004<000EnP7haOP02m@03
_c5b00;=00?><2H00W802LibHC6RHH2>P00:o`051UH?Z`400Z/4cP8a011Q<F5VYVJVoc4CZQ>ZaC0V
0S0015K=_Ld4S0DU0YH01066J`42J`8100<McLh00bD00gdC4`024`03mC:o03T01Ol300go1003o`H0
0_lF0005OX1n<Gh01P001<g><2H2LP0;cW9Q<J9QP8j0SXd00Z802c7>cS46cPIF3j/100:[1<h2<@0@
HC5QIZIVY_la4jXCZ/D`9P8`00AFcKg=18`01G:A3`4?00:F00@1QV/10V/20@077Lg>_LemH@044`03
mC:o0480000D00Go0P0;o`030?oo00<01_l300;o3002SP03P68b00:E00D10<k>3`02cP0<IW;>L/ib
<Lf0cJ:02_l01Oh?ofH`00;=0c4046XaJXDaLVH`IS8amGkeO_D59P030Oo>00:A00C0TG;>0bD01YIF
UVHaQP9[00B[_oi60c402/j=OHFRQJ:50[lh00;o0`02o`030?oo00801?l00`3oo`0600;o00@0oooo
0`04oaD00Xh00h1R0006000?3lk>IW;>L/ib<Lf0cJ:000:R00?>cJ800/d0237=<?h?ofH`0/d3<@0@
JS5ZQC5bIS1V<S7eO_Enm@DV00<1olh00Y403L2AL/ibcPnFEYIV<HH00V/01:^ooTH3<@0:cXemQJ:5
XXD2_`H00Qlj00004`02o`<01?l200Co00<0ool02@02o`040?oo00Co2`001I6RP36o00;e0`02LP<[
0/h02RK>AW9QSLf0_Hh9o`0=o/hVcRK>iGj0OX1ZHP024`9b01NVYGjUZQ>Z4jXb<2H`3eHa4gelHGbR
3`02:`043b^FQP8100UV0F/1:g8[cLh00/d00kemH@044`03<[l003H00_l400;o00<0ool01002o`03
0?oo00X00_l200;o0P02oa@000BAXX0a1`00178[:b/2cP0@9/i6LV6=cH2mSXemSH2=cP<?00gncRK>
9/kUOX1nP6YR008C0W805jJUOZFZ4jXCZS8`9S0?ES4COGaQO:8?008[00@?:iJ60P402FH1J`4[LR_=
cP02c@04_BDU4`<U00?o9@001alj00004P02o`@01?l400;o00<0ool02P02o`800_l200;o2`02XP04
HP6EU@@00/h0379Vc/iVcVJ6?83=P0:m00>R<Ol01_l01a=V<6H`<Ld01C403VXaXZ:5<S4bOS9nmGke
1BH0635E<J:0XW`NS<3>3fH?IXIVQVH[cR/a:`8a00[><C4aOJ:5X/h?>002o`<01?l00`3oo`05o`03
0?oo00L00_l00`3oo`0200;o0P02oaD00Z800f80000500;>00abI/k>I/iVQSb0cH02_@04XS6RcP;=
00X>3ohCIS1V<37=1C403VXaXZ:5<S4bOS9nmGke1BH0635E<J:0XW`NS<3>3fH?IXIVQVH[cR/a:`8a
00?><C401RD:7cX0000B00;o0`0;o`030?oo00X00_l200;o0P02o`/000BAXY6R0_D40003:lk>00?>
00eVcVK>3cc=S<fmcH3=00Go00bFIUH`:c51iLj0OX03JP:R00>5XZD017h02oEn9RJo9S8aOS5n00>R
00R0XWblL/ibcP:60VH01R_>cW8acP@a00O><@lC3li[03T00_l900;o00<0ool00ol900?o0`02o`80
0_lE0004TJ:AXPH000<[c/h00lh07VK>I/h??<f<cKg=P<emcG8?YYIVES0[<D7UcX1nP0=Z0Z800hFR
Y@04OP0;mGhV9[lV<S5n<Gh00j80282RO;abcW;>0XH2IP06:lk>LS7>13489@PO7@03oa/0000B00;o
2002o`030?oo00?o3002o`030?oo00800_l?0003TKl000H00/h01eH`c/iVcVH00Pl02/6mP;g=P<h?
UP42IP0=0DHV<F/aO>EnP6YRJP044`09YC5nOQ>Z4klb00:o00l1<GhaOS5mXQ>RS:9lcPl00/h036H1
3`1b0C41cS7><@H000=[0000>002oa`00_l200;o0P02oaT000>A00001P02cP07ES3>cVK>IP023`0:
`Kf0_Lf0cPnF0@9V00d1ARHaJc5liGj0JV9Z00@C00VU<Gin4jXC_c800[l03`4aOS5n<GfR4j:<XWc>
3`02cP0=IP4?0781<@7><Lha00099@LO7P000ol0000J00004P02oa`00_l00`3oo`0200;o6@02<0@?
00AV3lh?0/h018b=LPl2J`03ceHC009F00LCES3?A/ll00<a00MZ<J:RQJ8b009n00@bO_DC0RH05382
mODaEC5EXS60XX1lX[aV3VH?C@02o`<00_lC00;o00<0ool00`05ob<00S043`04IPo>3`;>00B<SG8?
0V/00lmF4`02EP074eH`cdK??003<@07JS6RXXFR<P02OP04<Wke4`8V01@b0_Ge<EDaEJ8aP::0O::l
IPiV3``02BD00olO7`077a/000?o00006P0001<00_l300;o4`02o`030?oo00801OlJ00Qb0Pl01<h?
7G`2cP08Y/jVITH1AP42J`09<F]lP7j0HVYR008C0Wh01C5nOS6Z00:o00<b0Kl00S4017haOS42H@09
4j8CS::<X/ib04l01_lD00?o1@02oad000<O00001P08LP8?00C>3ael0/h02:K>YVI60DH10V/02C5[
O81nP69ZHP024`9n00DaOWhaZP02_`03<P6o008a00An<Gha0V402A>R4hbRS:;>LP0=00PU00?o9@00
3Al800Co1003o`<00ol30003o`0000<01Ol<00005006oa@00ol400;o8P003W8?LPn6I/hNSF/VcbK?
0UH01A=F0Lm6009V0Xd0235Z<FZRZWhb0Wh0239n9Q<V0S8a0Xh0235m<GeU<Kda0[d00c7>002B008O
3@003W8?LPn6I/hNSF/VcbK?0UH01A=F0Lm6009V0Xd0235Z<FZRZWhb0Wh0239n9Q<V0S8a0Xh0235m
<GeU<Kda0[d00c7>000@00PU0`037`@02Al50003o`0000<000Go0000o`020003o`0000;o20001Ol0
003o00/0001K009b017>I/h?iLjVcZK>IUI6IZI[3`02YP06?8emOVYn0ZX00gjZOP02OP07<C:o9[lb
P002SP0;P7enOGiQILfmcG80U0037`h00W804LiVcPoUcZK>Y/iVETIVYV/?00:V00HlSGenJWh2ZP03
OZYn009n00La<[lV_c:000:>00^0OGimOV5UcKg=LP0B00039OlU008U00<Oo`0010027`T00al60003
o`0000<000Go0000o`020005o`000?l02@000ol0000<0000H005cP0FQ/k>0JH1YUI@TE2VP1=Q<F5n
4ghC<@9n00Pa5[lb_c60<@:000PaOS5nH@o=3iD01AlB00G>01J6c/h1YP6VEU2AD:J04f4aHGhCOQ<a
0Wh0234F_c:o<H0a0X00235n<GiQ3ld?5P02o`8O1`000al0000@0004o`3oo`8000Go0000o`020005
o`000?l02P000ol0000;0000I0002@mV3e0?D6H23`040005SGenJWh00ZX017jZOWh4<P0:9P:RL[f>
<HhaO@9b00<a0000U@067aD000T?IPm@3e1V0Pl010001HemOVYn00:Z00AnZWin13802RH2XW:mSS6>
<Gd2LP03<@0001L011lI0005o`000?l00P03o`801Ol<0003o`0000X0001a000@P1>0<F5n4ghC<GhF
<AHa_`@000JRcG;=L/fI00LO8@00480CP35QOQ=n4c5n5S4F<Kl40006X/ebcG;=6P057aT000Go0000
o`0H0003o`0000X0001a0004SGf=JP9n00>ZOZX00Wh5<Z802AlP0004SGf=JP9n00>ZOZX00Wh5<R<0
1QlI0005o`000?l05@001?l00?l<0000L@0018emSFX2OP03ZWjZ009n0c82_j801alR0004SGf=JP9n
00>ZOZX00Wh3<P:o8P077aP01OlG00;o3@00074000il4h0aHGhCOQ=n<AHa5P:oXP067b<000il4h0a
HGhCOQ=n<AHa5P:o8@087d<0001b0003OHeZ009n00BZOZYn0c800`8b002Q00047`0000<O90000gf=
JP02OP04ZWjZOP<b00<2<P008P087d80001b000<?80aHGhCOQ<a4aHa0[nW008O900033b0<F5n4ghC
<A<F<@:o90077d80001b008l00AmOWjZ1?l2<P030S800:H00alS008l00MmOWjZOS:E00<b00<2<P00
8`027`@000<O0000@000078000@lO3an1ol2_jP00alS0003?7`l009n00JZOQ>E4c82_fh0001c0003
O3`C00Oo0[nY00<O8`001g`l4hdC<A<00S400aJo_`1^0000L`02?003X_oo00Go00<b0000Z0037b<0
0S`2XP03<YDb00:E00<2<P00KP0007@000<lO?l01_l00kl0002X00<O90001SalSHda4`8a00<V_`00
90027dP0001d008l00>Rool00ol00`6o002Z00<O8`02?004XVFE<P?o00>o00008`027dP0001e0003
O::=00Co00<V0000ZP047b<000=lXXd01olT008OB00007D000=lSHd00Q<00c4C9P2^00037`000280
00=lSHd01ol6008O70000al000170000MP001SaUXS:E_mD000<lIOl01_l00`0O7`057a/00am80000
MP001Sb=4hda9[400olQ0003?8go00Go2AlJ00@OB00007H000JRIJ9UUKnb0003o`00020000>RIJ80
1Ol00`0O7`057a/011m80000o`0_0003o`0002@00ol300TO6@027`;oA`000?l08@04o`@00ol300?o
0`000ol0000400;o7`0;7aP000?o0000AP000?l08P000ol000030005o`000?l00P000ol00002o`L0
00?o00000_lN00@O0P077aD000?o0000AP000?l08P000ol000030005o`000?l00P001Ol0003o00/0
00?o00007@027`H01al400Co1@03o`800ol30003o`0000D00olh0000o`0R0004o`3oo`8000Go0000
o`020005o`000?l02`000ol0000N00037`0000L00al60003o`0000@000Oo0000o`3o00800_l:0003
o`0003L0003o028000Go0000o`0200?o0P05o`X00_ld0003o`0000@000Oo0000o`3o00<000?o0000
20000ol0000g0000o`0R0005o`000?l05`000ol0000b0004o`3oo`<000Oo0000o`3o00<000?o0000
20000ol0000g0000o`0R0005o`000?l05@001?l00?lc0005o`000?l00`03o`030?oo00?o2`000ol0
000g0000o`0Q00Go5`02oc@000Go0000o`0E0003o`3o03T0003o07<000Go0000o`0F00;o>@000?l0
LP05oaP000?o0000=`000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0
b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0b@000?l0M004o`800_m=0000
o`1e0003o`3o008000?o0?l0C0000?l0M@000ol000020003o`3o04`0003o07H000Oo0000o`3o04`0
003o07@000Co003o0P000ol0o`1<0000o`1e00;o0`02odd0002H00Co0P02ool0:@0009T000?o0?l0
0P000ol0o`3T00Co0`02ocX0002I0003o`00008000?o0?l0i@000ol0o`020003o`3o03X0002J0007
o`000?l0o`3G00Go0`04o`<00_l20003o`3o03X0002H0004o`00o`8000?o0?l0e@03o`@000?o0000
1@001?l00?l20003o`3o03X0002I00;o0`02ohh000Co0?oo@P02o`8000?o00000P02o`H000Co003o
0P000ol0o`0j0000o`0_0003o`3o04000ol:0003o`0000D00ol300;o>P000:X01?l300;oO0000ol0
000L00?o0`02oaT00_l=0003o`0004L0002[0003o`3o008000?o0?l0N`001?l0oolM0005o`000?l0
0P000ol0000A00Go00<0o`001`000`l0000300;oA`0009d01Ol300Co0`02o`8000?o0?l0W0001Ol0
003o008000?o00003P03o`d000C>:lk>1P000ol000140000V`03o`@000?o00001@001?l00?l20003
o`3o09`000Go0000o`020003o`0000`00_l20003o`0000P000D?LPmb3`02LP033`0000800_m60000
D`001?l0oom200;o0P000ol0000200;o1P001?l00?l20003o`3o09/00_l30004o`00o`/00ol<0008
:lha<LhacR/2cP03LP0000@000?o0000@`0005<000?o0?l0@003o`X000?o00001@03o`<00_nL0003
o`0000800_l:00;o3@02LP03:g8?009b00L?LPla:c4[00H000?o0000@P0005@000?o00007003o`<0
0_lI00;o3@000ol0002e00Go00<0o`00200013;Uc^D2LP07:g8acS7><@03cP03L/ha00D000?o0000
@P0005<000Co0?oo7@001Ol0003o008000?o00004@05o`030?l000L000<?00000`02ok800ol?0005
_/jnc[h00/h00b_><@02<@033c4?00;>00=bcZX01P02od80001d0005o`000?l00P000ol0000>00?o
3@001<h[c/h60003o`000:d00_l20003o`0000`000DacS;U<P02i@09LRH`9/hacS7>008a00CE<MDa
1@02od80001d0005o`000?l00P000ol0000<00;o0P000ol0000800053g8?LPl00W800`l0000200;o
[003oa8000PF<C7>_/jncPHa00<?<@l00/h01:[>Z/h60003o`000400001c00;o0`001?l00?l;00?o
300022_><C7><Lh[0/h00g8000040003o`000:L00_lD0008<LhacS;U<^D2cP039S0V008`00W>aJ[5
<MDaeC401`000ol0000o0000M0000ol0000200;o2P02o`d00W800b]b3`02LP073g8?<B/a:`060003
o`000:401Ol00`3o000A0004<LhacP8a00C>iLhC0PH4<@04cS;>ZP;>00CEc]GU2002ocl0002000Go
00<0o`00200013;Uc^D2LP04:g8acP8a0bD01<ibcS450003o`0008<00_lI00?o6002<@035S4F008a
00@64`HC0PH021<a<C4F<Lhb0/h01C;>1PK>00P000?o0000?@0007d00ol?0005_/jnc[h00/h012_>
<C479@03cZX000D00_n30003o`3o01H00_l20003o`0001D000S><Lk><LhacP8a00O><Lk><C0a00;>
00<aaJX00/D00lkUi@02i@P000?o0000?@0007/00_l20003o`0000`000DacS;U<P02i@05LRH`9/h0
1bD00c7E<@0500;oP`000ol0o`0C00?o6P000aHa5P02<@045S4F<@8600<a1Q<00PH0330F<C4F<AHb
cRH`9P8600?>1P001`000ol0000l0000N003oa8000PF<C7>_/jncPDa1bD00ljZcP060003o`000840
00?o0?l03P06oa/000Ce<OG>0S401<ha1S421P07<@HC1RHa9P02<@08cS7>Z/hacS421P03iLhV00P0
00?o0000>`0007H00_lD0008<LhacS;U<^D2cP049S0V<0LU00<aeC401`000ol000200003o`3o00`0
0_lO0005Z/k><Lh00S42cPTa00@V<BHa0/h02BH`9/hacS7>i@04cPL00_l;00;o0`02obX0001a00Go
00<0o`004@00137><Lh2<@04c^G>4`8613400lha9@029@05aMG>eND02002oh000_l:00Co7@002C7>
<LhamAKe5P02<@045S0F<@86018a1S0`5S0F<356cTK><2H`9P429P033bH?00T000?o000020000ol0
00020003o`3o02T0001C00;o6@03oaP00S400aHa5P02<@041Q<64`8600PC<C4a5S7><P;>00DbcPH6
cP080003o`0008P00_l30003o`0001X000ZUaJ[5Z/G><Lha0/h:<@0;9S4V<Lh`9S0VcS402Lh90004
o`0000Co0P000ol000020003o`3o02T0001C0003o`3o01H00_l20003o`0001D000S><Lk><LhacP8a
00O><Lk><C0a00;>00<aaJX00/D00lkUi@02i@P000?o0000Q@03ob0000<acS400/h03C7><ODFmAHa
<1H`5S000PH0634[<30F<1H`cTK>A/i6IP5V0FHV3bH?IPT000?o00001`000ol000020003o`3o02T0
001C0003o`3o01<00olJ00035S4F008a00@F<AHa0PH00c464`021P0<<1Ha<AHa5S;>9S0V0PH00lh6
00070003o`0008001?l00`3o000L0007cS7>cZG>Y@02cP08aLk5mC7><Lh8<@06:c4a9S5F0V/00dK>
AP09cP04I/iVIPP00_l80003o`00008000?o0?l0:@0005<000?o0?l03P06oa/000Ge<OG><@02cP03
<@Ha008600La1Q<69S4V008a00S><LjZcS7><@8600?UcRH020000ol0001l00?o8@000c75Y@02a@:U
00`aYJDaaJXacS7><Lh6<@039S4V008a00<VES000UH0130V<<l2LP07cPo>cPo>3`02cP03:`0000H0
00?o0?l01`000ol0000200;o:P0005<000?o0?l03002oal000JZc/hacS4500La00@V<BHa0/h02BH`
9/hacS7>i@04cPL00_l;00;o0`02ofT01?lQ0005<BHacS400/h0337><LhaYLjUcRHa9P8a00<F<2H0
0/h022/`:c3>EV]F0V/015K>ITH2IP033hH?00:600<?IP400/h00`4000070003o`0003H0001C00;o
2P04oad000PacS7><ODFm@L00PH04S46<30F<1H`<DK>A/h`9S0V0@8V00<?9Pl02@000ol000080003
o`00008000?o0?l0BP03o`<00_lC00?o0`000ol0000O008a00O><LG5YLDa00;>00<acU000S40153>
<Lh2<@0<9S0V<2Ha9S5V3eH`0UH01Po?L/mbcP8?0/h010o>3`l2:`033b/000P000?o0000=@0005d0
0_l30003o`0001X000VUaJ[5Z/G><Lh01`06<@0;9S4V<Lh`9S0VcS402Lh90004o`0000Co0P000ol0
00020003o`3o04/000Oo0000o`3o01400olU00079S4a9S4V<@02cP8a00H?<C4?cZD2cP07<BHaD2K>
9P02cP03:c0[00;>01=VJeI[cYK>ITI[UV^F3g9VLVIb00;>00<>cP002@000ol0000d0000FP03ob00
00<acS400/h01S7><ODFm@L00PH02C4[<30F<1H`cP04o`0;AVH1IP5V9PlV3fH02@000ol000070003
o`00008000?o0?l0A004o`<000Oo0000o`3o00`01Ol00`3o000R008a00?><Lh00S400lha<@02cP08
eLk>cS7><JD2cP03L/i@00;>00M@<<k><<iV00;>0VH01iK>cYK>UPl00/h2IP;>00YVcRK>Jlh[cR_>
2002ocD0001F00Co00<0o`0070001lhac/jUcZD00/h01lG>aODacRH01@001C0a<C4[008a00@V<EI[
1_l7cP04I/iVIPP00_l80003o`00008000?o0?l0B`001ol0003o0?l02@04obP00/h0137><Lh2<@03
cS7>00GE00G><Lib3`02<@0<3c4[:`l[3bIV<6H?0VH00liVcP02UP08cPo>3lh?cPl2cP033lk>00;>
00E[:f/[cP090003o`0003<0001C00?o8@000c75Y@02a@:U00`aYJDaaJXacS7><Lh300<a00<V<BH0
0S4012IF<5H6o`03L/h?00;>00<?cPl00/h00b/000060003o`3o00L000?o00000P02od/00_l30003
o`3o00L00ol20003o`0002@000O>9/ha9S4V008a00<V<BH00S401<hacS42cP083lh?L/ibcU02cP08
D7;>cPo>3lh53`:F00<?UPl01VH01BH?9PlV00;>00<Vc/h02P000ol0000b0000D@04ob4000Da9S7>
<@02cP0<<LhacS6UcZG>9S4V0S4011H`9/h39@07:c3>EV]FJ`06o`04IPn63`:600<?IP400/h00`40
00070003o`0005P000?o00000P02o`@00olZ0004:bK>9P;>00<acS400/h0137><Lh5e@09Jg9[LV]b
<@la008?00O>3lh?IS1V008?00EVcVK>9P02cP073lk>cPo>3`02cP03A/k>00O>2P000ol0000b0000
<`03o`<00_lC00?o0`000ol0000O008a00O><LG5YLDa00;>00<acU000S40153><Lh2<@039S0U00@U
00HaIPmF<5H8o`053lk>3lh00Pl2:`043b/U9@L000?o0000H004obT000?>0Lh00/h01RK>cRHa9P8a
00<V<BH00S402Lh?9PlVcPo>3`02cP033g8?009b00O>L/k>L/ib00;>00<?cPl00/h019H1IP43IP0;
9S0`9PlV3c4VcRH00/h00bH0000800;o<P0003@000Oo0000o`3o01400olU00079S4a9S4V<@03o`07
<@la<@o>Y@02cP06<BHaD2K>1bD01LiVJeI[00Wo00H?oombIW82cP@U20000ol0001J00Go9@0017;>
L/h2D004cU1b:`?>00<Vc/h00/h7<@K>00AVJli@0/h01PmVQ/ibcPEb00O>LW;>L/hV00S>00A6c/i6
1<h2<@?>00<a<0002003oc40000]00Co0`001ol0003o0?l03005o`030?l001`00ol3008a00?><Lh0
0S400lkoo`05o`05cS7><JD00/h00g;>D002cP03D2DU00DU00C>IVJF0/h;o`04cRK>J`HU1`02oeP0
0ol20003o`00028000<[LR/01W800`mb3`03LP03:bKE00?E00Hac/hacS42cP039/k>00;>00P?cPl?
cPo>3`;>00<?<BH00W800b]b:`023`03:lk>00O>00<acTH00/h00c0V<002cP03<Lha00;>00<acP00
2P000ol0000D00?o600003@000Oo0000o`3o00T01?lR00Go00@0c/ha0ol2<@03c_oo00Go00G><Lib
3`02<@063c4[:`l[1bD016K>I/h2UP04cPo>3`Oo1<h69@P000?o0000E003obL000CecW;>0W802<ib
cW9@cU0a0W80135bcS42cP07<BHa<BH`9P02<0039S0V00EV00o>IVH?IRKnc_k>oW;>LS400W80135b
<@l29P0<3bH1<BHa9S0B9Q8V0S400bH`9P02<0039S0V00/000?o000050000ol0000G0000<`02o`<0
00?o0?l01`03o`8000?o00007`07o`03cS7o00Co00<V<Ol01_l2cP083lh?L/ibcU02cP03D78U00@U
00?>3`l00`l2UP043iH?IPGo00@V3bH?1bD90003o`0005001?lX00Ce00=b:g800S402lhacZ;>X/jR
<Lha00CE00Hac/hacS42cP8V0lh05`o>cVK>3lhacS4V<BHa9/hacS7>:lh[00C>00M6c/hacS7>008`
00LV<<k>:lh[00;>00<ac/h02`000ol0000E0003o`0001H0000d0003o`0000800_l400?o9P08o`03
c_oo00Go00?>ool01Ol02F]bJg9[LS4?<@023`04cPo>3`<U0Pl01FK>I/ko00;>00D?c/k>3`04o`05
A/k>cP001BD:0003o`0003<01Ol200;o4P03o`8000?o00009002cP;e00C>mLib1342XP03<G8a009b
00@aLS5b0/h01c7><C0V<2H00S0016K?I/l2IP05cVK>cVH00bH01Ok>o/kn00Da00ib<G8aL/hacS7>
<BHa9P8B00PV4RHB<2H`9P8`00@V3bH?2`000ol0000D0003o`0001H0000m00Co9P09o`03c_oo00Go
00<a9_l01?l01PlVcPo>3`;>00<?LPl00W801libc/ibcW800/h00`ooo`02o`04UP5V0@=V00LV<30V
3bH?008012D00bH0000800;o;P05o`070?oo0?l0o`020003o`0000X01OlZ00C>1?D00j[e<@03<@:R
00`aLZ9bXS5b<I7EcS43cP09<LhacVK>9/hV00K>00<a9S400bH04@Ha1PK><LhacS46<@K><Lha00;>
00PV<BHa4S0BAP;>00<[cR/01/h;00;o50000ol0o`0G0000>005obD000EbcW;>D00Ao`<a0ol3cP04
IV_>D0;>00H?IXK>L/h5LP03cW;o00Go1lh014K>cTH3cP039@0000801RD600?o=@001?l00?l20003
o`0000L00ol^000:9/k><LhamJXaZPLa01O><J;>SC7><LhaYC6U<LhacPo>3lhVcP02IP03cVK>00=V
00?><Lh00S402@Ha1PK><LhacP05<@04AS56<@;>00<acS400S001c5V<Lh[cV/01lh<0003o`0000@0
0_l:00;o00<0o`005P0003D00ol20003o`00028000<[LR/01G8@o`03<Lha00;>00<Vc/h00/h020o>
3`o>3lh?0/h00`la9P02LP04:g8[3`Ko1Lh00c7>AP02cP05<2H`cRD010069@P000?o00005003oaT0
00Oo0000o`3o008000?o00001@03obl000`V4/hVcRK>mC7e<OD5<@03XS5R00@a01:A<I6AcU3>D<hV
<2H`9VK?IPl2IP05cVK>cR/00bH2m@La0ZD02346<@K><LhF0/h022Ha9S4VA/i60/h02RH?IPmV9PlV
3lh;00?o1@000ol0o`0T0000<`03obL000CecW;>0W801LibcW9@00[o00?>ool00_l00bH`9P02<003
9S0V00EV013>IVH?IRKnc_k>oW;>LS5b1_l03bH?9P4a9S4V<18V4RHa9P0:9@T000?o000050000ol0
000H0007o`000?l0o`020003o`0000800ol20003o`0002`000LV<2HacS7>008a00FZ<JXaZP03<@03
mC4a00<a0Xd2<@0:cS6U<JDaY@o>3`?>00EV<6IV<002IP03<FIV00La0PH00jXa<@07<@04AS7><@;>
00`acS7>IS5V<FI[cV/2cP05Jlh13`403@000ol000030003o`3o02@0000`00Co:004m@03LR]b008a
00C><LjR2Ol2e@03<Lk>00@000?>9RH00lh04`o>cVK>3lhacS4V<BHa9/hacS401_l2cP07A/k><Lha
cP02<0049S3>cPXU2@000ol0000E0003o`0001P00ol300;o0`03oc8000PV4RHBcRK>5P8`00@amC7e
0S401WhaOV8aHPHa0Y40135@cTH2cP0<<2H`YVH?IPmVA/h[0/h012_>mLh2m@07cS4amC7e<@02Y@08
<@Ha1S4FcQH2cP0C9S4V<Li6cTK>LXH?IPmV3bK>9P02cPd000?o00000P000ol0o`0T00004`05o`80
0_lB00?o0P000ol0000T00;>0_D01<kecW84<@:R00@aLS5b1_l01LhacS4V00@000D`I/mVc`02IP05
cVK>cVH00bH01Ok>o/kn00Da00=bool00_l02LhacS7><BHa9P024P099Q8V4S0V<2H`00HU2P000ol0
000D0003o`0001h01Ol20003o`0002h000D`AS0B<0024P03cS4a008a00>ZmJX00_D02C7e<OER<F8a
HP02S@08<Hg><G8[cTH3cP053jJVIZH00VH015I6EVH2cP041S46cP;e00O>1PKeZ_Da00:U00<aYC40
0c45cP08<Lk>cUK>IW82QP0<LV][Jc3>0Lk=c/d?2`02o`<000?o0?l0900000h01Ol01`3oo`3o0?l0
0P000ol0000:00Go:P04cPCe00>ZmC400c42XP04<G:RLPKo00C><Lk>1P001<hVcRH6cP03<BHa00<V
0146<@H6cS7><Lha1S46cS7><@02cP089S4V<A8`4TH2cP05:lh[cS401BD:00;o50000ol0o`0L00?o
00<0o`00=0002DK>cTHV<2H`:`06<@07ZS6Z4oDCm@04<@065/hFcQK>0W800c5b:`02LP8?0/h00`o>
3`02EP05<5H`EVH02C42ZP03<JXa008a00?U<2/00S000b_><@02cP07AS16AS2Fc`02IP03cfI[009V
00G>I/iVc@02cP033lh000T00_l300;o9@0001H000Co003o0P000ol0000700?o;P002RK>cS7><OFZ
<JX7<@0;cS6RcXdacS7><JD02@000lhVcP02IP03cVK>00=V00?><Lh00S402@Ha1PK><LhacP05<@@0
0/h00c7><@02<007<FHacR_>J`07cP`000?o00001002o`X00_l00`3o000I00?o0`000ol0000a0003
cS0V008`00PV4RHB:bH`5P8`00<FmC400ZX00c5n<@02OP03<F8a00<a00?><Lh00/h00bK>9P02cP08
L/jVYVK>I/h2AP03<4K>008600d`1S3e1S46<ODamC6U00;>00?5cQH00S425P05cW8VLUH00/h059K>
UW:63f/?Jlh?cPo>IW8>LPib2`000ol0000W00004`001ol0003o0?l00P000ol0000500?o;`0032HB
cRK>9/ke<ODam@Da00>R<F801340194aTI4:0004I/mV3`9V00G>I/k>:`039P;e1c42Y@05<@Ha1S40
10002LhV<BHa9TK>AP02cP0:9PmV3fHV3bH?cP/00ol50003o`3o02@01?lX0004<J8aXP`00b/01DK>
cTK>00<`00<[<3400S401<haZS42ZP0@mA?emC4F<1H`5/hFcS5b<@<?00l13`4?cPo>3liF<5K><Lh0
2C42ZP08<J[UiC;U<R/2<003:c0a00;>01G?<4JF3iH?UVI[IV/?I/h?cPo>3lh00Pl2LP/000?o0000
9P0001<000Oo0000o`3o008000?o00000P03o`8000?o0000;0001bH`9S7><Lh00S401JXaZS6Z00<a
00?e<C400c42S@8a00?><@002002cP05IS1VIS000VH00c5VIP07<@8600>Z<C401S46000=cS7><LiV
<FHaIV_>J`02cP05JlhU9@403@000ol000030003o`3o02@000Co0?oo8003<@:R00TaSJ:=XS6R<J80
0/d027bmcLg>L/ib0/h01g;><<hVcRH00S000b/`:`02<@03cZZZ00>Z00?e<OD01c401lhacW9Vo/h0
0_h02/ibcW;>I/iVcUH5cP041S46<@8600da1S7eZ_Dac^G>iLkU008a00K>IW9bcW83cP04U/jFIP=[
00>F<9H00/h01VK>c/haLP8a0/h:00;o9`0001@00ol300;o0`03oc8000PV4RHBcRK>5P8`00@amC7e
0S401WhaOV8aHPHa00>A<@0020002JIV3fH?ITK>:`02cP04:lkecP;e00O><C7e<ODa00:U00@a1S46
1P003bHa9S7>A/i6cW:63fH?IP049@039/h000`000?o00000P000ol0o`1600<a00O><LjR<J8a00:=
00@aXS6R0/d03Gg>O7c>Jli[L/ibcW800VH01liV:b/V:bH00S400aHa<@02ZP04<JXa4`8600LC<C4a
IW9V009b00=Vc`l00/d00`o=cP02LP;>00IVJlhVcRH2cP0C1S0FcS46<@Ha1RIF9UK5c/G>9P02IP0B
cVK>LRH?UPo>3fH?IPn6<9H`0VH01c1V<30V<2H00/h00bK>000;0003o`0002@0000J00Go0P000ol0
000^0005<4H`4S000Q800lha<@02<@03Z_FZ00;e00TamC7eHS5R<F800Xd0136=cS460006cPnVYVJV
0VH015I6EVH2cP041S46cP;e00O>1PKeZ_Da00:U00@aYC4a1P000lhacP02cP04E/iVLP:600=bJbD0
1BD01<g>c@l;00;o0`000ol0o`120006<LhacS7>1C401<haXS43XP06<J8aHC5Q0/d00kebcP02cP@?
00C>3lh?2<h00c6Z<@02ZP0B<C0a<C0a<1H`cRH?cVH`IS1V0W800`mbLP02LP09<E0a<LhacS7>00Ta
00C><Lha0/h00c;><@02cP0:3lh?cPo>3lh?cPAV0/h3IP;>00=VcRH00/h00bH[cP02cP03<@0000X0
00?o0000900001L00ol00`3o000d0009A/k>ARH`9S0[00Ha00NZ<JXCmA?e00@a00LFcQK>5/ib00D0
00=b3`l00/h00`o>3`02EP05<5H`EVH02C42ZP03<JXa008a00CU<2/`1000137>AS02AP03<9K?009V
00??IV/01RD01Lg>cPo>00X00_l300;o@0000lda<@07<@0BcS7>XS6R<Hf0IF4aHJ8aXS4`0/d00c3=
LP03LP04cW9bIP;>010?9RH?9Pla5S4FZQ<F4aHC0PH021<6<LiVcVIb0Pl05/l?3g;>L/ibmLkecV_>
9/hVcS8FcQH2cP0=1S46<LhVERIF9PlV3`029P04I/iV3P@?0/h010mVQPl2QP03cVH`009V00La:c0`
9R/a00;>00<V<BH02`000ol0000T00005@03o`<000?o0000<@000lh`9P02<0089Q8V4R/V<1H2<003
5_Da00:Z00<aOS400Wh00c5R<@03<@03cS7>00;>0`029@08L/jVYVK>I/h2AP03<4K>008600d`1S3e
1S46<ODamC6U00;>00C5cQHa1000178VLUH2cP09U/jFLXH?J`m[00DU00IVLPib3W8;0003o`0003`0
00RA<Lg>cLhacP8a00C><Lha0/h4<@04cWj0cP9P0/h2P003XS6R00Ha0lh23`05L/ib3Pl01lh01c7>
<C4`<C000S40130acRH2cP0=9/h?IS1V3lh?LPmb3`03LP07D34acS7>_P02i@La0UH0137><FH3cP0L
<LibTG8?cPo>3liVcPmVcVK>9S4VI/h[<B/VcP@[0/h00c7><@0:00;o9@0001801?lX0004<J8aXP`0
0b/01DK>cTK>00<`00<[<3400S401<haZS42ZP0@mA?emC4F<1H`5/hFcS5b<@DU00d13lh?cPo>ES1F
cS7>00Ta0ZX0236ZiNDbiC8[0S000b/`<@02cP0>cc16UPnF3iIVJfI[3fH39@043lh?cP8?0W8;0003
o`0003@00/h02@o=L/ebTG:AP003c@03<Lda00@a00C>HS5U0Wh0281nP7j0H81P0V400c6RXP02XP04
cC3=:`9b00?>L/h00W84c@0>9/k>c_DamLke<C0a<3421P03<<h`00?>00>FIYH00/h00fK>i@03LP06
cW9bXW9[0/h00kkU_P02i@03cS7>00;>00PaE/k>IUK>IP;>00=b3lh01784cP0JL/k>9/j6I/h[cR_>
IR/a:c4[<B/a:c7><Lh2<@/00_lS00004P001?l0oolP00<a0Z802C6=XXfR<J8aXP02c@08O;g=cLib
cW82cP07L/h`cRK>9P02<003:c0[008a00?>ZZX00jX00oDam@07<@04cS7>LPLU00S>L/iVcVK>EPG>
00@6<@Ha0PH03C46<OFZmC7>iLkUc^D00S400liVo`04o`;>00BFcYIV0f/00iH`UP02cP06I/k>cS5b
0S42cPX00_lc0007:`l[cPo>3`02c@03cW;>00:000<acC400/d3<@:000<aP3401S40181UP6D2H@04
<F4aXP8a00<[cR/00/h00`o>3P02cP0L3W:0P<fmL/ibcU3>D<hF4aHC1VH`IS3>UVJF3`:600<?I[h0
0lh0337><LiZcVZmc[g><P;>00Lb5/k>I/iF00;>00D?cPl?LP053`9b00/a5W;>L/ibcRK>9P02cP0D
:lh[9S4[<B/a:c4[<Kla9S4VAR/<0003o`000240000d00<a00O><LjR<J8a00:=00@aXS6R0/d03Gg>
O7c>Jli[L/ibcW800VH01liV:b/V:bH00S400aHa<@02ZP04<JXa4`8600LC<C4aIW9V009b1bD00lib
LP02cP06IV_>9/hV0/h04`H`5/ha1S46<@HVERIFaLk5cRH00VH00lkoo`05o`0:cPmV3fH?QS2F<09V
00L`IS0`9S0V00;>00<VcP002`000ol0000_0009<0l`3g8aLS6=00:R00=mSGd00/d2cP06<J9R<F8a
0V80335ROWj0OX1nP63>H0:000?><C4013401g8[LRH[LR/00W802;j0LX2RTLg>0S401oDamC4`<C00
0lh00bK>9P02:`033ljF00;>00RF<^GU<^EbcP9b00>RLZ800[d00c6m_P02i@03_S4V00;>00<VcUH0
0VH00`4?0@05cP0BaG;>L/ib0C41<LhacS7><BHa0RH01C4[<B/V00<[00@V<C7>134=0003o`000200
000`0006<LhacS7>1C401<haXS43XP06<J8aHC5Q0/d00kebcP02cP@?00C>3lh?2<h00c6Z<@02ZP0?
<C0a<C0a<1H`cRH?cVH`00DU00<?LW800W802C5@<C7><LhacP09<@04cS7><@;>00<bcS400/h00`o>
o`06o`039FIV009V0/h3IP;>00=VcRH00/h00bH[cP02cP03<@0000X000?o0000;P000lh?cP023`;>
00^RcZ9Z<H0aP:8aXP04<@06P360P3601c401H1UP6F0008a00<b<BH00S4022Ha:c0V<<h>0/h01C;>
cLg>00>R0W80253>D<hF3fH?0VH00c1VAP02Z`03cXH?00:600=V9[h00/h00kk>cP02<@08J/iZ_Ljm
c[d2cP0<:fK>cVK>3fK>3e0?0/h019K>3c42cP0I5S4FL/ibcW9n9WhVO/h[9S4V<B/a:`4[<@02:`:o
00<VAR/00TH<0003o`3o0240000]0003cC4a00La01;><LjR<J8aSH1UHC5QXS6R<C02c@03<<eb00=b
00C>LW9V0/h040lV9PlV3c4F<AJZ4aHC5Q<21P084`HacVK>IW823`0FcbDU9LibcW;ec_G>JlhVcRK>
<QK>5P;>00d6<@HacRIF9UHV3bH?008V00=Vc_l01_l29@03IXH?00:600?>IS000VH01c4[<30V:c40
0/h00bHa9P0;0003o`0002`000L?IVH?I/mV00=b00@aLXfR0Xd01Wf=4gfROP:R00<aHS400V803C5R
OWiUOX1nP63>H3400Wh00c5n<@03<@07<<k>9/hV:`04_P0<LX20LZ:AX/3><OEb1/h022H[3b/?UPnF
0/h01S7><NDbi@@a00S=SLg=_Lfmc@9b00d[LRK>3j/?Z`4?0Lh?00;>00<aaLD00/D01LibcW8100Da
00C><Lha1BH00b/V4`029P03:c4V00La00<100002`000ol0000O00009`00294acLk=cS7>0S401<ha
cS42cP@a00C>OX3>0V02cP:000>R<J801S43cP8?00EbcW8>3`07cP07<Lha<C0a<002<@04<37>9P;>
00dVcPmV<6H?cPmb3g8?00=b00M@<C7><Ljn00;U1c42EP04<LhaIP8000K><LibTG87o`8U00iVcVK>
9S4VI/h[<B/VcP@[0/h00c7><@0:00;o:P002?k>o/knIPmV0Pl01j;>XV6RHJ800Xd01X2R<J8aOP:R
01:0HX20HX1R<GiUOX1nHWhaOS42OP03<Gha008a00@B<1;>0RH02c0Vc/jncS;=<F4a00FR00BALW9b
0VH4cP05A/jFcYH00lh02VK>I^G>mC7eSC42S@;=00N=cKg=_Lh[00;>0W800j/?IP02IP08JiK>U/ha
c/D2cP03mC4a00Ha018VORIncS4V<BHa:bH[9R/b_b/3_`05AS56<DH03@02o`H00ol300;o4P000200
0/h02@o=L/ebTG:AP003c@03<Lda00@a00C>HS5U0Wh0281nP7j0H81P0V400c6RXP02XP04cC3=:`9b
00?>L/h00W84c@0>9/k>c_DamLke<C0a<3421P03<<h`00?>00>FIYH00/h00fK>i@03LP06cW9bXW9[
0/h00kkU_P02i@03cS7>00;>00LaE/k>IUK>00@000<?07800g85o`<U01K>QVK>:lh[c_l[<B/a:c4[
<B/acS7>0S4;00;o:@02cP063lk>3f/?0W80235b<GjRP8da0X000c6R<@03<@08P360P360<H02<@03
OC5E008a00<Z<BX00S406c8a<S4V4RHB<2/C:a<bcS8aaF4aHC5QTC6AXP02`008cG;=L/h?cPl2cP0B
U/hVcVHVIRIV4c4C<A>=<Hda0Wd00c5mcP02_@03cPl?00<?00La3fI[IV/6008a00LF<AHamC7e00Ta
00=n5S400S403BHa9TH[0B/1mFJo:kl00UH00dH[AP02AP039P0000X00ol60007o`000?l0o`0B0000
7P001b/?:lh?cPl00/d00libcP02P003<Lda00;=0c42P003<H0a00Ha00B0IH1U0V40135Q<J82<@03
:lh[00;>00<?cPh00/h070ibP83=_G;>L/i@cU3>5Q<F4`IV<6H`cYIVUPl2QP033fJn00?>00`acS7>
J/iZ_LjmcS82cP07<QK>cVK>EP02cP033lh?00H000H?LW8a5W859@039/hV00;>00<[cR/00_l03b/a
:c4[<B/a_c4V<BI6:`0<0003o`0002X000UVJc1[<6/[<J800S402V60SH1mSA=m4gd2XP03OV8a009R
00<aOS400Wh00c5R<@02HP03<Gha009n00<aOS400S001bH`9RH`9S000RH00kha<P06<@BR00ZAXZ9b
cG;=I/iV0/h03PlV<2HacS6Z<JXamC7e0c401jYbLS5b<Lh00/d00lib3`02cP8?00?><3000c42cP07
<LhamA?e4`02<@034c4a008a00G><LhacP039P8a00@19Q<V0S800c4V<@02_`06ES4a<@4a3`000ol0
00030007o`000?l0o`0B00007@002C0?<0mb<G8aS@02XP03OHem00;=0/h01S6RHS5R<@9R00`aHWin
P7j0OX1PcV02P003cS4a00@a00Mb:g8V:g8[009b00RnP7:0XY7=cP8a00Oe<ODa<34`00?>00<VcRH0
0R/00`o>UP02cP08US;UiC;UL/h2LP03XW:R00:m00<a_Kh00^D00kha9P02cP039/iF009V00<13`00
1@001lEbcW;>LP400bD02<hacS7><BHa1?l00c4[9P03:`049S4acP@a3@000ol0000[00093f_>:j8a
LS5b00:R00R=P::R<J8aXP@a00^0XS60<H1m<GdaE@02<@03:S4Z008a00`b9S4B9Q8V4UH[4b/24`0=
<LDaaF4aHC5QTC7><@02P00=cX1bcW8?cPo>LRK>9P02cP039U0a009@02Da4c4CSLjZcZXacS7><G8?
<0l`cVK>I/i[1Q864S4F<ODamC7e00Ta00LC5S4a5RH[009600<[AR/00_D016Ke:a<2EP034dHV0096
00<VIP003@000ol000030007o`000?l0o`0B000070000lh?cP023`;>00^RcZ9Z<H0aP:8aXP04<@06
P360P3601c401H1UP6F0008a00<b<BH00S4022Ha:c0V<<h>0/h01C;>cLg>00>R0W80253>D<hF3fH?
0VH00c1VAP02Z`03cXH?00:600=V9[h00/h00kk>cP02<@08J/iZ_Ljmc[d2cP0=:fK>cVK>3fK>3e0?
cP0500;>00lF<AIbcW;>LWhVORIncR/01Ol01C4[0B/a008[0[l00bI6:`02AP`000?o0?l0;@000f/>
J`02XP03OF6R009Q00>=P<h00V400gf0O@02O@08<A<a<A<aOS42OP03<Gha009R00<aOS400Wh01c7>
<Lh`9S000TH02S0V<2Ha<S4b<C89<@04cI7=T@;=0/h04G9[LW8V<2H`ZS6Z<JXamC7e00JZ00laLS4?
cLk=cV_>3lh?cQ801342cP0=<A<amA?e4oDa4c4b5P02cP035/ha00;>00Pa0C4a0C4b0@8b00<1_eH0
0[l015H1<C420@035P0000d000?o00000P001ol0003o0?l04P0001X000L?IVH?I/mV00=b00@aLXfR
0Xd01Wf=4gfROP:R00<aHS400V803C5ROWiUOX1nP63>H3400Wh00c5n<@03<@07<<k>9/hV:`04_P0<
LX20LZ:AX/3><OEb1/h022H[3b/?UPnF0/h01S7><NDbi@<U00<acHd00/d01;g=_Ld2LP8000`VcPn[
3j/13`7>3lh300?500G>L/ib0@05<@04cS7><@Ko00LV4bHV:c4V00La00<100002`000ol0000/0003
cV^R00JR00b=P8fRHHj0SX1mHGd2XP04<H1nP09n00=mOS400V80235nmOGU<Lha0/h00dIFAP02EP03
AS0C008600O5<LG5<ODa00;e13401H1b:g8[00=b00?>L/h00/h00c3><@02<@0<ZS6ZZ_DaSPK>Z/jZ
0/h03G;>L/h?L/ibcVK>IS400PH04Q864PKe<ODamC7e<OG><LhacP8a00LCcS4acS0[00960iH2m@0>
IYJFE[mFQV^6AVHVIRH=00?o0P02o`<00olB00005`002?k>o/knIPmV0Pl01j;>XV6RHJ800Xd01X2R
<J8aOP:R01:0HX20HX1R<GiUOX1nHWhaOS42OP03<Gha008a00@B<1;>0RH02c0Vc/jncS;=<F4a00FR
00BALW9b0VH4cP05A/jFcYH00lh01FK>I^G>00DU0Xd2c@05SLfmcKd0100016H?Z`l3IP08JiK>U/ha
c/D2cP03mC4a00Ha00@VORIn1ol01bH[9R/b_b/00kl01DHaAS5600d00_l600?o0`02ob0000DacC6R
<@02XP08OGj0SJ:0XS42SP08<F4aHJ8aXS42P008<GdaOC7>:lh2m@03c_DV008a00BFcUHa0UH00lh6
<@021P07aC75<OEn<@02OP03<Lha00?>00<[cR/00/h024K>A/haLS4`0S402c0aD50aSPJ>1/jZ00?>
00AVc/k>0XH00g;>LP02cP03<@Ha008600<B1Q800_D03C7e<ODamAHaYC6U<JD00S400a<a<@02EP0H
<2]6:iH1UP5VUVJFIUI[:f/[9VHVIRIV3P000ol0000J00006002cP063lk>3f/?0W80235b<GjRP8da
0X000c6R<@03<@08P360P360<H02<@03OC5E008a00<Z<BX00S406c8a<S4V4RHB<2/C:a<bcS8aaF4a
HC5QTC6AXP02`008cG;=L/h?cPl2cP0:U/hVcVHVIRIV4`LU00PaOGdaOLjmcPH000La3fI[IV/6008a
00LF<AHamC7e00Ta00=n5S400S44o`09:`4[0OEV_b^o009F00=6:dH00TH00bH0000:00?o1P001ol0
003o0?l08@001Hf`O:9m009Q00>RP8d00V401lj0OH1m<Gd00S4011<aOS42OP03<G9b009b00`[L_Ge
iOG><Lh?QPl2AP03cRK>008a00<`<C800c402?DCmODC<Lha0/h022]b:g8aLS5b0S400lha5P02<@05
5ZXaZ/D01C400j[>9P02cP039VH?00;>0Pl4ZP044S4a4P<a00En4c4C<@024`0=<LhacS;></hbcQH?
9P02cP039/ha00BF00@1UP6F0P402hH1QP4?IQH15P5[00l000?o00006@0001/000UVJc1[<6/[<J80
0S402V60SH1mSA=m4gd2XP03OV8a009R00<aOS400Wh00c5R<@02HP03<Gha009n00<aOS400S001bH`
9RH`9S000RH00kha<P06<@BR00ZAXZ9bcG;=I/iV0/h02PlV<2HacS6Z<JX79@08ZW9b<G8ac/d6008?
00?><3000c42cP07<LhamA?e4`02<@034c4a008a00G><LhacP039P8a00@19Q<V0S800c4V<@02_`06
ES4a<@4a3`000ol000030007o`000?l0o`0Q000><LePXV2ROHbRcZ:0XX02SP09<F4aHJ8acW;>009b
00=[cV/00/h022_>:oG>mLha0YH02<jFc/iVcVHa0PH3<@;e0S42OP03<LhF00;>00HFc/ibcP03cP05
LS5b<C000S40230aD50aD0J>0PH0105Vc/h2IP07ZfJ6cW;><@02cP03<@Ha008600<BmC400_D04S7e
<ODF<AHaYC6U<JDacW;>LP9F00<`3fH00YH01W8?LVJFIP8?00T[Jb^FcRIV9VH00V/>00?o6P0001d0
00T?Jlh[XS5b<G800Z8028f0XZ8aXS6R13402h2R<H0aP7daOC5E008a00<Z<BX00S40338V<A8V4RHB
ER/C:`8C00daaC75HC5Q<F6A<Lha00:000g>P7;>LPo>3lib9/hV00;>00<VD3400U079@08cZXacS7>
<G86000@cVK>J`HB1Q8a5S7e<ODam@Ta00LC5S4a5RH[009600<[AR/00_D016Ke:a<2EP034dHV0096
00<VIP003@000ol000030007o`000?l0o`0R0009SH2`O3aQXV60009Q00?>HGd00X001c5m3g8?cPl0
0/h00g;>LP03LP0=:g8[mND?LPn63hH?0002cP059/ha<C000S400a<a<@024`;e0S401<hac/h2J`06
:f/0035b0S400lha5P02<@035S4a00;513402C16<2K>IPmV3`02J`03:f^Z00>Z00LB<C4C<Gha009n
00<a4c400RH01c7><LhbcS800/h03`m[3f/VIPmV3iKn0Oh1oP020@0>Z`6[0@mV3fHF0F/1J`4@0003
o`0001L0000N0003J`i[00:R00=mHJ800V400hf0cP02H@03OH1m009m00Pa4c4a4c5n<@9n00<aOS40
0V800c5n<@02OP07<LhacS0V<002AP0:<2H`9S4b<C8a<PTa00C=TLfA0/d2cP0>LV]bLRH`9S2Z<JXa
ZS459@BZ00DaLS4?c@0500053lh?cQ801342cP0=<A<amA?e4oDa4c4b5P02cP035/ha00;>00Pa0C4a
0C4b0@8b00<1_eH00[l015H1<C420@035P0000d000?o00000P001ol0003o0?l08P002GbR?62`?:9Q
P002XP03SJ:=00Ib0/h0178VI/h2LP05P<g>P<h01?l01H2RXYIF00800lh01FK>1S46008a0_D2<@04
mC7e<@;>00E[EV]FLP050005cV7=HLd01C42a@0B<LF>1UI6ETIVZfJ[Jg;>L/ib0/h01J[><@Ha00;e
00DamODam@039P03<Lha00=V00/ac_ooT@K>1/eV9P02<@05cE3>D<h00V/01/2RO9K>UP;>00EVJf][
IP02UP030@0000`00_lH00007`000li[XP06XP0<SH2=XV6>P8j0OF5m0Z801360OX02OP03OGha009R
00PaO_GeiC7><@;>00=6ETH00UH00dH`4`021P07aC75aC7e<@02m@@a00F0LR]b:`03LP03cW;>00;>
00<`cS400S401JXaZZXC00<U0P002LjZc/ibcW;>3`040004I/iV<@86018B1Q86mC7e<ODamC7ecS7>
<Lh2<@074lha<Lh`:`02AP>F0_D03VJFUUJoEXI[QTIV9VHV3@03o`800_l300?o8`001F5lH:9l009m
00_>XZ9Z<FYbcW;>T@030@033c4a00:000K>SHdaSC42S@03<Hda009m00<a00001@001Pl6<@Ha1P;e
00<amC400_D00c7ecP02EP03<5H`00H000C=P3601C401E0aD341009F00<1EV/00Z/43`04cW;>LP;>
0S401S8a<C;e<@;e00<[<B/00S402B/Fc/h?o`nAQ@06<@089S4V<@I@cU02IP03<04100;=00dlO<k>
3liV:iJVIZH100d000?o0?l05`00020000DacC6R<@02XP08OGj0SJ:0XS42SP08<F4aHJ8aXS42P008
<GdaOC7>:lh2m@03c_DV008a00BFcUHa0UH00lh6<@021P07aC75<OEn<@02OP03<Lha00?>00<[cR/0
0/h024K>A/haLS4`0S401C0aD50a00L00/h00fK>cP029@H000<a1S400PH00a864P02m@0=<ODamC7e
5S6U<JDaY@02<@034c4a009F01P`:dH[UP6F0FJFIYIVEV/[Jb/VIRIV9VH>0003o`0002`000@lX[0l
0V405J:0HHfRSJ9b3oib0C1F<5JR<F4aH@02c@07P<j0cBEn9@03OPP000@a5S4F0c400a<a<@04<@9[
00@aJc5[1P001HdaHLeQ00@a0/D01S4V<DH`AP@100cVJf/[cLk=c/en<Gh2m@054oEn<Gh00aH49P05
cmIbo@H013401lh6cPIn<BH00S400c8a3`03J`030FH100:m00JR?7c>3lh20@03UP6F008100=V0000
30000ol0000E00008@001Hf`O:9m009Q00>RP8d00V401lj0OH1m<Gd00S4011<aOS42OP03<G9b009b
00`[L_GeiOG><Lh?QPl2AP03cRK>008a00<`<C800c402?DCmODC<Lha0/h022]b:g8aLS5b0S400lha
5P02<@055ZXaZ/D01`0012K>cRH39@H000FZ4S4a4P03<@05OQ<a4c400Q<03C7><LhbcS;></hF3bH0
0/h00bK><@04UP040IH1UP8100^60HH13fHF0AH1J`0?0003o`0002/000AlHF1l0Z801gfRX/haJW80
0Pl20@05:`4`3c000S44P00;OXdaHVhaKS5^OC402@001346<@H2m@034_DB00;e00<amKl00UH0131F
0IH40004OJ:0<@:01S400li6cP02EP07Jj][Z`7>3`02LP03cWda009m1S40238a<ODa:c4[0S401nH1
iW8a<3400XD6<@039S4V008600AoIS1V10402S7=<GaQO7;>LR/2YP06IZ/1Z`5[30000ol0000E0000
8@003S7=H:9PXWf<X/jRP::00Xh02C5Q<F6R<LibcP02LP03Jli[00;>00P[cR_ec_G><@:F00S>U/k>
I/iV<@860c42m@8a0Wh00c7>5P02cP045/k>LPG>00Eb<G8a<002<@05<35@D3401`02cP03IRDU008U
1P000c46<@021P034_Da00;e018amC7e5S4F<JDaYC6U<LibcW82EP03<0mV00:F00Ib3g9VUVH23`09
:f/[U/hVIRIV009[3P03obd000>RO3`00V402j9QHC5Q<F7nQP7V009600P?<5JRSF4aH@:m00]Q<F5n
9GhUOS5n<@0800055S4F<A<0234015I[<F/3UP@000C>X/6R0/d5<@059S4V<DH010401NIV0FH1008[
00d?cLk=OS5n<ODCmA<a00@F0RH01loFcg;m<@H01C401`HbOWha9S400S80336oJf]V0FJFSKf=_@:R
00G=c/g>UP020@03IP5V008100?n9_h02P000ol0000D00008P002Hf0/7`lHJ9QP002H@03cV5m00:0
00LaO@mb3lh?00;>00=bcW800g803B]b:oGU3g8?QPn63g800/h01BK><C4`008a00<C<C400Q<2m@8a
00C><Lk>0V/01R][Jb/aLP8a00?><AH00S400aHa<@02a@03<@0000<000<`9/h01BD500:Z00LB<C4C
<Gha009n00<a4c400RH01c7><LhbcS800/h03`m[3f/VIPmV3iKn0Oh1oP020@0>Z`6[0@mV3fHF0F/1
J`4@0003o`0002/00W`01calXZ;=<Ld00XH05`7VAR_>3ljRTJ:=HH1QP;eRJV9^<Gha00=n00EmOS:0
c@0500081S7><ODBmA82m@08_eJo_f/1UPl2Z`03Jj]b00;=00MmX/7=HLha00;>0156cTK>AZ/?iP7>
I/ibcZ;=XP02c@08SLdaOS7e<C84<@0?:c4[iP7Volh6<@Ha1XDa009n00@bOWhb0S421P09_bJo_fJF
0F_000:R00C=XWal17802:/1Z`5[0F/10_h00bH000060003o`3o01D0000R0009O:8lH;0lXV6000:R
00>=XXd01W82cP04LRIVcP9b00F0cLj0cP04o`07P::RUS6AXP03cP05Jlh6<@H00S42m@8a00Ce<ODa
0/h03f]FJeIbc_D[mH3=HLeQc@05<@;500PaaC56<4IFAP9V1BD40006cZ[><@Ha0_D01C7emC7e00<V
00<acS400fH02c7>oonA1/h6cFHV008a00G=D<i@cP02J`06`:9lU/jF0/h01FI[Jf]V00:F00<10000
3002ob`000Yl?3al?<fR<@o>0Pl02]JVeYJ60HJA/344P008OX1ZHVXaKS42KP04<GlaO`8a1`002U0a
mA;e4_EF_eH2_`8100N[0Z^[0FH100;=00>0S8000/d027da3c56cTH10Z/00`l1oP06cP04<GdaO@:0
2S404R/a:`4V3bH?<34`<C1nZWjZ<P8a00<b1Wl00PH01klV_kl3J`l00VH02370<L2RO67>0W802<h1
0Lm[0Oh10/h00`o>00090003o`0000<01?l200;o1`0002<000EQO62RO002O@0;cZ:RJS5ZL/ibcY40
0`400`la<@02P006cXf=<Hda0Xd00c6=<@02O@03<Gda00>R00P?cPl6<@Ha1P;e00<amC400_D00c7e
cP02EP08<5H`U/h[cR/2c@03P36000Da00E@<E0a0@02EP030EI[00:[00@?9BDU10001C7><C4b008a
00<bmC400_D00b/a:`02<@09:aK>cPoo3i6500Ha00PV<BHa1U3>D09V00<`0@400/d03Calc/h?cVH[
UZIVYP403@000ol0o`0[008l00MQO65lcS7>00:F01;F0MH1QPo>3lj=O:8aHGfmOC42H@039GhU00=n
00HbOS9n<Lh50003<Lha00@a00UF<EHaES5[0@000P403@o>3lhacC7=O:9QXS400/h2<@040@l1iP<1
00EV3b]b:`02LP0>X/fRcHdaSC6=9S4V<BH35P;V1<h010Ha1S42OP044ghC<P9n00@a<S4b1Kl010;_
QVH2QP>R00?=P<d00g800b/?IP020@07oU3n3bH[LP0:00;o1@000ol0o`020003o`3o00H0000T0004
?::`?09Q01FRP66=XXfRLPonLP4`ES1FXS5Q<F400/d01h3>P<dUORD00gh0335n<J:AXV]bJaHa5P<a
00<C<C401342J`0?<F/aJiKe3oD?mHdaHLeQ00@a0/D01S4V<DH`AP@100CVJf/[10001<en<Gh2m@05
4oEn<Gh00aH49P05cmIbo@H013401lh6cPIn<BH00S400c8a3`03J`030FH100:m00JR?7c>3lh20@03
UP6F008100=V000030000ol0000Z0003?7al008l00_=QPn6eZKFYV^FIP03cP03XS`a00>0019nP6YR
JS5^<FhaZWlaOc4b<AH300030C5@008a00PBmLk>E[mF_`810`006:]V0FH1_C6m<G:0X/7=3g8?LPmb
Z`7n3`;>00=Vc/h00/h0136=P7d2P004cS6RXPHa00@[0Lm60Pl00bH?9P02<@07JS6ZZWjZ<P02<@07
OS9o1RJo9P02_`0=0c9AIW;>cH3=`::>XP02LP09cV/?Je015PmV00;>00<>cP002P000ol000020003
o`00008000?o0?l01P0002@000AlHF1l0Z801gfRX/haJW800Pl20@05:`4`3c000S44P00>OXdaHVha
KS5^OC5m<Gd2<@08cS`?cS46<@H2m@034_DB00;e00<amKl00UH0331F0IJ[L/ibOJ:0<@:01S400li6
cP02EP07Jj][Z`7>3`02LP03cWda009m1S40238a<ODa:c4[0S401nH1iW8a<3400XD6<@039S4V0086
00AoIS1V10402S7=<GaQO7;>LR/2YP06IZ/1Z`5[30000ol0000[008l01[2cLf=cYK>YV^FQYIVJfIb
TGb`P660_H1ZHP9Z00=n<Gh00ZX01C9n<Whb00<a00U[IV]VcJ;=cUH00/h2EP03<@5[00@00YH02<hV
c/k=_Lfm0Z802l7=`J;>L/ibJ`m[009V00Ce9_DV0Xd00c6=S@02c@03X/f=00:R1C401PoVi^JROPB=
00>>OXh00Wh03JYnZS9n<WhbOPHV_bH00[l00jhb[P02m@03c_G=00;=01:=cHg=Jc1[<52EIU1VD:;>
X/h;0006o`000?l00_l20003o`3o00H0000U0003XW`l009Q00^RHF4aHC5QoXH1iP02AP083c1FXXeQ
<F42_@0HHC5QOREn9GhaOS5n<X3=P<f<XQHa5S4C234015I[<F/3UP08EPo>3/jR`J82c@Da00DV<BHa
AP040@05iVH1IP400R/03@o=c/en<GhamA?e4c4011H29P07cmK?L_da1P05<@071S9nOS4V<@02<P0<
<Km[JfH1IYJ=_Hfm0Z801Lg>cLjF008100=V0FH00P400ohVoP0:0003o`0002`001UlXR/?:`l[LXH1
QV/aJc6Rl7b0OF5m_Gda009Q00<aORD00Wh01Q<bOS8a9P8a0V/0235[<@7=TLh`0UH40003J`000080
00BF<4HV0/h01BJ=cHg=00FR00>AXR/00V/02LmVcfK><LhacP03<@07SLg=HLeQ<@02S@08<LnVY/o>
Y/h2OP0<<HdCSHinSWj>4ghC0Wh0138a<S44_`030[n^00<100Ge:oG=cP03c@05SLg=<0400_h0155[
0@42LP04TC6A<@X00_l20004o`00o`8000?o0?l01P0002H00W`01calXZ;=<Ld00XH05`7VAR_>3ljR
TJ:=HH1QP;eRJV9^<Gha00=n00QmOS:0cH3=cP9l00P6<LhamA;e4P;e00RoE[noJ`6F3`:[00=[Zg80
0/d01gfR`LeQcS400/h04DK>A/i6Z`oV0LiVcW;>X/fR00;=00R=cC5n<ODa<P@a00l[<B_V0NKocPHa
1S46QC400Wh0139nOS82<@8600Vo9[noIYH1Jl000Z801<fRO7`4LP08Z`6[0F/1J`42oP039P0000H0
00?o0?l0;P001L:<L/ib009V00<[UP400VH00`56<002XP08/69RP7j0JV82JP03KZXb00:Z00=o<Gl0
0S800b^o0@02IP090II6cJ9lE/iF00T000@aAS4V0/h4<@0HP360<G;=cW;>LPmV3fK>mBKe9_F=<Hda
0Xd01:;=XS42c@0<<@o>3bH?9PnR<J9U0Xd026DaJS5nZWjZ0Wh01S9n<Wjo9P>o00Tb0Oh1LWdaOLh0
0/d0182R<J82cP03IPnE00<?00S>D<k>X/jRcP/000?o00000_l300;o1`0002H000Yl?3al?<fR<@o>
0Pl02]JVeYJ60HJA/344P008OX1ZHVXaKS42KP04<GlaO`<a010F<C5l`35@<ODBmA;eE[mF0[l20@07
Z`:[Z`5V0@02c@03P8b000;=00Qm<@laA/i60@:[00<?0Oh01/h0135m<Gd2P0Xa018[<B/19PlV3c0a
<34`OZYnZS82<@03<PIo008600No9[no0f/?009V00Pa`370XWaQcP9b00S>0@7?J`7n0@;>00<?cP00
2@000ol0000300Co0P02ob0000F=_G`[c`02LP0;cc1FJc56<4JllH000W`0166mOKd2H@03<GhC009n
00HCOWhb<BH2<@03AV/a00<100FmIKflEP0:000:AS16<<hV<BJ=<@:=00[=SLf=<@lacVK?0VH01S5V
<LhacP<a00N0SKf=cF7=009b00S>LZI6Y/jVcP9n00<aSA<00Xd03Gj>OXhCOQ=n<C8a<S401;l01@8c
I/h[00;>00B=<Hda0Z8012]b:g840@05Jg9[TC400Y40178aLS4L00009P02?007HGaQO<hacP02UP0B
eP7F0HH?cPo>SGbR<F5m_Gda0V400bEn9@03OP07<WhbOS7><@02cP04<H`acPDa00MF<EHaES5[00@1
00d?cPo><LdacGbRHJ8a00;>0S40104?0NH30@05IPl[LR/00W803Z;=X/f=<HdaSBHa9S4V0aH2iPC>
00@6<@Ha0Wh011=n4c82OP04<C8a<PFo00@2khIV0XH3XP03cH3=00=b00<[3fH00P401oi@oPlV:g80
2P02o`D000?o0?l00P000ol0o`0O0005O<fmcKd00VH4EP08AS16<96R/3`2HP04OX1nHP9Z00<bZS80
0ZX00c8a:`02<P0=0Kl1_iI6UTIVSC6=7`090006<DI6<DH`0S400c0a<@02<@07P360P<ib9P02LP0@
I/h[c_DVmBKeSS6><Hk=<@;=00laX/eV0B^F9PlV3j8aXS400Xd026DaJS5nZWjZ0Wh01S9n<Wjo9P>o
00AV3g8a0W800c5m<@02O@0=<Gg>:lh?IU41ZlibcP02XP03cZ;>009m10000fH0000E00009`000cal
O002?00;cHH?Q]JVeZI[UVH00lh00j8l<@03P00BOX1ZHVXaKS5^<JYo<Gla<S4F0S4016H1<E02<@08
4_G>cUJoE[l20@0K0Z/2ZfH1IP6m<KdaLX2R`Ld?LPmb3g:[0Oh?00;>00=Vc/h00/h0136=P7d2P004
cS6RXPHa00@[0Lm60Pl00bH?9P02<@07JS6ZZWjZ<P02<@07OS9o1RJo9P02_`0=0c9AIW;>cH3=`::>
XP02LP09cV/?Je015PmV00;>00<>cP002P000ol000020003o`00008000?o0?l080001GbR_J:m00AF
00=VATH00TH015I6l7`2HP09OGjmHWiZOZYn00:Z0Wh02c4b<THaAS81AVJV00;>00>m7al01@001Ld`
cdK?009600K>:lhV<BH2<@:=0/h01Lg>c/hV00;>00QVcVK>IS46<@8600V0SX2>cKg=_Ld00VH032]6
0IIVcZK>YWjROP>=00mnSWj>ZWjZOZXbOS;E_bH00[l01C93IVHa00;>00B=OHem0Z80136R:fH2D@0;
Z`7>LV]bJj:AXS400W801lh?D6K>I/h05@0002P00S`06/;=cHg>U/jVJiJ6UVI[IW:AO;20HH2mP6YR
0VX00ghaOP02ZP05<WhbOS800c402F]VJfK=X/g>EP02cP9F00N[0F^[0Z/100:F00S>9/k>cKg=_@:R
00_1cL6RcW;>LV/?J`02IP04mBKe9P:=00<aSHd00/d00j;=S@02XPDa00H?i^KVXWh4S@03SWj>009n
00fZOZXbOS9n<Wh69[lV00:o00>^<Zh00_D00lkec@02c@0BSLf=cF/`Jc1@UFI@IU2RcZ;>2`001_l0
003o00;o0P000ol0o`0Q0008O35bLS1F<342IP06<C1FES1F0W`017eUOVD2OP034ghC009n00<CORH0
0c4024HaA[l10[nV0/h47`<001C=cTK>A/i69S4V<BHa9S7U<LhacP:U00@ac/o>0S001c5V<Lha1S40
0PH01H0aP36=00G>00jF3fH1YVJVXS6RSX2><@:=00anSWj>4ghbOS4b<C82e@08_`:o<S6=<Lh2P005
cS60<H001<h05>H?3f/?cPlaLS5b<G8aLPmb0@l10VHF0000:P006GbR:`l[3b]bQP66Jc5[<J;`O81m
HGfmOC400V400c5n9@02OP064c9n<S4V0S42J`08<F/a0LfAcS02EP05J`m[3f/00`42UP03<4HV00;>
00DVSLf=c@05XP03TJ8[009[00W?I/mVcS7><Lh00c401hg=cF7=HC400Xd0237?YZK?cZK>0Wh0336=
4hf>OXinSQ=n4`9n00@b<C8a1;l00`:o[P030@05mB_ecLh00ld01Hg=cC0100;n00AAJ`410W80194a
TC4:00;o0P001?l00?l20003o`3o028000HlXZ;>ETH2IP04AVI6<@9600O??69ROGmm009n00AZOZXb
0ZX03ZDb:c:o0Kl1<P9@0U1V1Al00j:0<@02XP089/lVclh[cR/2cP07<Kk>_/hacP02<@;>00Ha9/k>
E/h3:`049R/a4P8a00R><Hk>9PlV3`:F00=V0@400VH05c0aSHem<GdaSFDaJS5ZZQ>Z4jXbOS:Z00:o
0P<01IG><Gda00:=00<aSC400Xd022H?9Po^0F^[0/h03fH1cP6RcZ9b3g8?LPo>3`0G0000:`001L:<
L/ib009V00<[UP400VH00`56<002XP08/69RP7j0JV82JP03KZXb00:Z00=o<Gl00S800b^o0@02IP0<
0II6cJ9lE/iFZ`n[0Pl029I6UP6FAS4V0/h4<@0HP360<G;=cW;>LPmV3fK>mBKe9_F=<Hda0Xd01:;=
XS42c@0<<@o>3bH?9PnR<J9U0Xd026DaJS5nZWjZ0Wh01S9n<Wjo9P>o00Tb0Oh1LWdaOLh00/d0182R
<J82cP03IPnE00<?00S>D<k>X/jRcP/000?o00000_l300;o90001WabLS5V<@9V00a[<EIF<F//O7eU
OVD2OP034ghC009n00<C<C800c400dHaAP02_`030[l200HO00=QXQ<00/d02TK>ARH`9S4V<BH5i@03
cS7>00:U00@acS0V0S001lhac/hacS400PH2<@03UJZZ00?>00>6UYH00P42YP08IZJR<J:>P8h2P008
SA>>OXhCOS82OP03<S4b00;E00P2_e:U<HdaS@:000G>P80aP003cP05iU4?QPl00/h010o>LPl2LP07
cPkn0LmVc`0I0000:`001HfmO2_?009b00_?<5I[<DH`A[caP002O004HKem_@9Q00<aOQ<00Wh01Q=n
OS8a9P8a00=6Jc400`401KeU_KaF009[018?IP5V<0l`UTH`AS3>9S4VSC42S@0:cHg=SC4?<LiVc`9V
00HaIS7><Lh3<@07P8fmSLeQc@02LP08cW:VAZK>Y/h2OP03<HdC00:=00enSWj>4ghCOS4b<C8a00Bo
00D2<fK>:`02cP04SC6=<@:R00@[LR]b10401F]bJi4a00:A00Ab<G8a>@001Cc>cU3>009V00e6<4H`
cdK?A[1ROGmm009n00eZOZXbZS:U<R/b_`6o008b00<2D08021l01lhaXZ8acbH00Xh00bK>:`02cP08
I[k>_/hacS42cP039PlV00;>00AVEVH[0bD01bHB<LincWh00/h01PnF0IH1IP810VH0131VSHd2<@0A
OC6=P8eZ<FZZ4jXCZS9n_jX00[l01`<@ULhaOC400Xd00c6=<@02S@09<@l13f^F<9K>009V00X?IW9b
3Y4?3P4?6`0002/000ElcKg=_@02IPAF00Q6<4H`TJ:`?09R00AnP7iR0VX00c:Z<P02ZP03<S4[008b
00`1_`6oUTJFAVJ=<Hd2O004Z`l?3`:F00=69S400TH00c56<002<@03<34a008a00N0<H20cW8V009b
011VcR_>mBKe9_F><HhaS/da0/d03c6RcFH1:iHV3bH?XS6R<@02S@08IC5Z<GjZOZX2OP06<WhbO[lV
0kl016H?LS42LP03<Gda009m00daOLh[cPmVD@6[cW;>00:R00?>X/h00Wd40003IP0003<000TlLS5b
D6]6JdH00V/024K?A_9ROGim0Wh04FYnZWjZ<ZDbYDHaAS4bD;oV00TO00>=cLd00c401S2>SS0VIP?>
1>D00lhacP07cP03I/h?00DU00bZc/jZcZ[>IXJFQYH20@9V00jVIU3>D7bRP8j0SH2=SP9n00QZOZYn
ZS9n_`;E00RoDPHaP8g=S@;=00@acC4a0/h00b/1cP02UP0;QYJ6UPo><I5b0G800lhL0000;0001GbR
_J:m00AF00=VATH00TH015I6l7`2HP09OGjmHWiZOZYn00:Z0Wh02c4b<THaAS81AVJV00;>00FmSJ8l
_@04c@04<<m6c`9600K>:lhV<BH2<@:=0/h01Lg>c/hV00;>00QVcVK>IS46<@8600V0SX2>cKg=_Ld0
0VH032]60IIVcZK>YWjROP>=00mnSWj>ZWjZOZXbOS;E_bH00[l01C93IVHa00;>00B=OHem0Z80136R
:fH2D@0;Z`7>LV]bJj:AXS400W801lh?D6K>I/h0=@001c4?<F/aJc400V/0135[<O82O@0FOVEnOQ=n
4ghC<S4b<DHaAP6o[_mbcPPO00f=cHdacS7>9S3>I/hV00;>00<?:`l00b/01W8[L/iV<09V00<?cRD0
1RD3ZP07UJZEcRK>QP020@=V0P433`9l00LaSX2>P7iQ009n00=QOS800Wh02C8a<]Db0U;><@03P008
SH2=SC6=<B/20@0=3iJF3hH?QP4aD78?cP0Q0000;@0027`aLW8`ES0a0VH01S4`EUH`EP9l00AmIGiU
0Wh00a=n4`02OP034ghV00<a00Q6<DJo0@:oYP;>01^VIKfRHLdCcLi6cTK>ARHa9S4V<BHaiC7><Lh0
0ZD0137>clh2<007<FHacS46<@021P05P360<Hd01Lh03YH?IP6VIZJR<J:>P8ha0Xd037j>OXhCOS9n
<C8a<P;E00Ro0[lb<HdacP:000G><H0aP004cP0DiPl?J`o>3c5b<G8aLS5b3g813`42ISL000C>D516
1F/00lm6c`02HP0=OgeoOVYnJS:Z<ZDbY@02_`050@8bkP000`l00c4O7`047`04OX3>P0@a00XVIPmV
3fH?:`mb0/h00g;>cP02LP06cPo>cPmF1bD2cP03<Lin009V00@`IZJV0`4046^[3eH?O<il?7daSH2=
P342JP034jXC00>Z00NoZ[no<@K>008a00g=<Lg=<LdacLh1cYK>00:F00K>UR]@3b/T0000;P001SbR
X/iFAP9V00A6ITHa0TH01lllHV9mOgd00Wh016YnZS82ZP0FYC8[<[l1_`4b0U02D6HaLZ9nSJ:0<@:R
00PVcbK?cR_>:`;>00La_/jncS7>008a0/h01S4Vc/iFcP<[00@V:c4B0S4028haS/hV3bH?0YH00fH1
0@02IP0G<36=SGdaOC6=IC5Z<FZZ4jXCZS9n<ZX00[l20`05ULhaOC400Xd00c6=<@02S@089PlV3nh1
Jj/2cP0?IP7>0J;>XW8?LPmb3lh?03T000Da3g9[<@02J`:F00HaJo5mOVD2OP044ghCOP8b00ha<S5[
<DH1[Z8acLk=LP8O00>=cAl00Ql01lf=cLhacR/00/h05FK>3oh`3c0?:i5bTG8?c`l`IS1b3`079@:Z
00<[LRH00/h01RH1YP7fIPD10hH027`lSX2>P7j00Wh00f5n<P02OP09<]DbeC82<Lha00:000<aSH00
0Xd0236=c/h?UPnF0/h018H?0OlV0000;`001WabLS5V<@9V00a[<EIF<F//O7eUOVD2OP034ghC009n
00<C<C800c400dHaAP02_`030[l2008a00?><C400V403Z8CcLe6cTHV<2Ha9S4V1ND00lhacP02Y@04
<Lh`9P8`00O><Lk><Lha00860S400iFZZP03cP03QYJF00810ZH026JVXS6RSX2>0X0028dCSWj>4ghb
0Wh00c8a<P02e@080[mBYC6=<Hd2P005cX20<H000lh01NIA3hH?00;>00@?cW8?0W801lh>oP7?I/l0
?0000g;>LP03J`0BUPnFccaROgeoOVYnJS:U<ZDb0kl02382kZ8aXX2R0al01h3>P::0<H000S44cP04
IPl?1P;o00<aLS400W800c5bLP02c@9b1Ol59@06L/g>0Lh10VH5YP0:0JI[EPl13`6FO08l00HaSH2=
P342JP034jXC00>Z016oZ[no<@H`L/ibcG;=<Ld?c@02IP083YH?QPnFog8W0000;`001Cc>cU3>009V
00e6<4H`cdK?A[1ROGmm009n00eZOZXbZS:U<R/b_`6o008b00d2D0;VLS5b<GjRP<ha00:R00<acbH0
0Xh00bK>:`02cP08I[k>_/hacS42cP039PlV00;>00=VEVH00R/02BH[9Q8acWk>OP02cP063iH1UP5V
0P42IP04<6J=S@8a015m<Hf0SFXaJZXCZQ>Z<WjoZP02_`070a2EcS5m<@02S@03<Hda00:=00Ta3`4?
JiH`U/h00VH02PmVLW8>T@l>0@ln00053g8?L/d00YH01lh?c_1ROWd00Wh00fYnJP02Y@04<ZDbJ`>o
00MB[Z8aXX3=00<O00F=cHfRP002XP03cG;>00C>00e@o_laL/dacF6R<J8a009b00<aL_l02ol01W`[
c/ib0@:V00KfYZH1YZ/2YP0<QYIFUV/lO82>P8f00Wh03VYnZWjZ4oFoeKl6<Lh`0/h01G;>L/da00?>
0VH2cP04Q/j6oBT0000`0009?78aLU1[AV]6009[00Q6cdKbHWenO@9n011ZOZYnZS:U<ZE6<DHa<U2o
1>H0135b<G82XP03SLg=00<a00H`SXh`9VH3cPCU00?><Lh01lh00fK>IP05cP0<Z/k>Z/jZcVJ6UXJF
0P42IP0>YVI@cU1lXX2>P8f0SHh2OP08JWjZOZXbO[l2e@08_e86<H2=cHd2c@04<Lda<@;>00<[0Lh0
0YH02hJFQYH?cS6ALP5b00?>A`001Pn6l7enI@9n00@COWha0S803C43Jf/b0h0aP66RHLd00Ql01;dU
_Kd2P005cC7=cJ800W801Oh?cPo>009b0S42c@09X/jRcZ8V<BHa00_o00G=XY7=LP039@070BD1Z`6[
o`020@03EPm[009[0W`013b0OX02OP03HGhb009n01<CmC;E_eH?cPo>3liVL/h[mB_e00?>00<?Jkd0
:`00038000La3c5[<F/a009[00@aJc7b0Wd05WiUOWhCOQ=n4c8a<S56<DH1_jkoL/h2LP04SLf=cP9Q
00f=cHdacS7>9S3>I/hV00;>00<?:`l00b/01W8[L/iV<09V00T?cPo>:f/[Jb/00jX01iFZULhVcXH0
0P43IP810`l2O007<Hj0SX1nH@02OP03HGhb009n00Tb<C;E<P9BcS400h0028f0SHdaSC4[0P403@nF
UPn63hH1<E1b3lh0C@003UK`HWmmOgiZOS9RYC:U0kl00`;^<@02SP<a0al05X2=P;f=_Lg>cG;>3jK>
QPn63hK>0Lh2H@Ha00<V<BH02ol01J:0S;f<00HU00P?Y_ooYV^FEP9[00P`IS`aP8f0S@9Z00laZQ>Z
<S6oZ[n[EVH?L/h00S42LP09<G;>L/h?<@mb02`0000c0004cU1@APE[00??A/l00V803GmmOgiZOVXb
ZS:U<ZD00[l01@42<^h000<?00Dac/j0cP02XP04OX3>P0@a00XVIPmV3fH?:`mb0/h00g;>cP02LP07
cPo>cPmF3`02LP04cW;>LP;>00<acWh00VH0131VYZH30@0@Jj/?EPmlcW`lOC6=P8f0<@9Z00<CZQ<0
0jX01knZ_kla1/h00S403LdacLdacC7=cP7>U/h00YH01/jF:e0?:e4000C`lGiU0Wh011<aOS42<P08
<@=[Jc;e4c42P003XV4O008O00JRO::mP;d2P005c@l10@l00TH00lh?<@02cP0<P<j0P37>OS5n9S4V
0S4016HaIS45o`06cHg=cJ:A1RD01:_oool40@9[00MV<6HlP7j0009n00iQOS9nmA?e<]FoEYK>9PCe
0/h012_e:oD23`03Jkd002`0000d0005<@mbJc400V/2UP06<F_aOGiU0Wh011=n4gh2<P0L<C8aJc56
0JjR<Lg>cG8acHg=SF4acHg=cS7>:`;>01IVcPon<0l`3b^ALY5b3ll?<6H`LPmb0/h010l[Jb/2ZP03
:g8V00;>00HV0JH1mVH50@>600Ql?8j0SX1nP09n00=QOS800Wh02C;E<]Db0S7><@02P003<Hf000:=
00PaSLk>3iH?UP;>00B63`7oD`003?8lSX1oOS9R<V:U<PBo00<2<C400Xh3<@8O00f=9C6RL/ebcG;=
3jJ[00;>00@VcS7>0S401f0aXZ8aJS400VX02C4V<BHaA/i6cP03o`8O00HV<J8aP<d69@Co00FFJj/V
Z`04IP05O7f=P8d00VX00c5Z4`02<P0D<C83EXH?I/iVcS7><G8aL/i@cW8_0000=@000g;>LP03J`0B
UPnFccaROgeoOVYnJS:U<ZDb0kl04S82kZ8aXX2RP8g>P<j0XX0aP08a1<h016H?3`H2o`03<G8a009b
00<aLW800/d2LP0@cW8VcRK=L/i6`G;=cP7>0@9V1JH02P6VJeH?0@l1UW`2?006<Hf0SH0a0VX00a>Z
4`03ZP0A_jZo_c46<7;>L/ebcC7=3ld00VH020jF3hH?U_mbE0005<kaSX2>P7iROV:U<V^oJklamC7e
0X00334O7an=_GbRO35b<@;>0f/00fK>3`02cP0<<LhaH35PXS6ROVYn0c4011HVI/h3IP03U/hO00<O
00C=SLeQ1BD5o`05ZbJ[9V/016H03liQOH2=P6YnJWke4oDC_`06cP;e00S>L/ib_I4?oC00000e0005
3g8?L/d00YH01lh?c_1ROWd00Wh00fYnJP02Y@04<ZDbJ`>o00IB[Z8aXX02c@07SKf=cHfRP002XP03
cG;>00C>00e@o_laL/dacF6R<J8a009b00PaL/k>9/i6cP9b00=6cW`00W`01B_>cW8100:V00KfYZH1
YZ/2YP0<QYIFUV/lO82>P8f00Wh03VYnZWjZ4oFoeKl6<Lh`0/h01G;>L/da00?>0VH2cP04Q/j6oEL0
01;al81nP7haOS5n0f/3Jc8Cm@l2cP03Jg8O008O00C>P<j017802VI[JfK>3lh?cPl3cP0=P<j0P1>0
OS5n<QHV5P029P8100AV0EH11Ql00ldac@049@Co00D1AP560@02:`0<IP4?O3amHGf0HGhC0_D02A?e
4kmV<2K>9P02cP043b^m_3D0000m00063hK`OGiU0Wh011=nOS42<P0<<@=[Jc83P360HJ9Q0/d00bFm
9@02_@:000G=<Lg=XP02LP05oPo>3lh00W82<@;=00nRcZ;>XRHa9S7>3c5V<FH012/2c@0>XY7=LPmb
3`4?0J/1ZiH20@03EPm[009[0W`013b0OX02OP03HGhb009n01<CmC;E_eH?cPo>3liVL/h[mB_e00?>
00<?Jkd0F@002Sc`P8j0<V8bHZD4_`05YC4?IPl00VH00`lO7`06c@03cV/?00;>00P?<FHaIRIVcP9b
00haH35PXS6R<F[E<MDa5P8a00>oIS400YH00f/O7`057`03H34U00HU01D`YZHV3f]@LU3>D<hlO7el
OHFRQC400S802S42_j]VZfH?U_li0000?P003UK`HWmmOgiZOS9RYC:U0kl00`;^<@02SP<a01TUSH20
SH2mSKg=c/ebcPnVcXH?QPn6cP7>009Q1S4072Ha9/i6cTK>D<i@cU3>XX2<_HabcW;>LZH?YP42YP03
JiIF009[00P`IS`aP8f0S@9Z00laZQ>Z<S6oZ[n[EVH?L/h00S42LP09<G;>L/h?<@mb05/000o`P7j0
OS5n<Gh3J`=[</h00Pl2cP08:alO7i7P<Lh2P004LRK>9P;>018?cPo>LR]b:j8acZ;>P1>04c42<P03
<BHF008V00<19P400UH00`4O7`077`LU00`1mPl1o`lVcRKn3`449@04HA<C4`;e00XCmC:oIS2F0IK>
>P0003l000C`lGiU0Wh011<aOS42<P08<@=[Jc;e4c42P00;XV6R_BFRO::mP;d00X001Ld?0@4?0096
00?>3c400/h0383>P80acWhaORHa9P8a00EV<FHaIP04:`04cHg=c@:R00BA3c0?0PH01:/1UYH40@9[
00MV<6HlP7j0009n00iQOS9nmA?e<]FoEYK>9PCe0/h012_e:oD23`03Jkd005/000W`P8j><V8bHYD0
1;l2UP05EYH?I/h00al01E2RD7`l00;=00=b3g800XH04G9Vc/iVL/ibcS5bP<f0<H0a00;E00daeC4F
<FJoI[m[3fH?00LO00<a9BD01BD01oKn0E36AXH00Pl00fH?IP049@06XXFRQJ8b0Ql01P:oZ`m[3c`0
000o000<lSb>P7mn<V8bHZDb1;l00`8a<@02SPDa00f=9C6RL/ebcG;=3jJ[00;>00@VcS7>0S401f0a
XZ8aJS400VX02C4V<BHaA/i6cP02IP08D2H?9S6R<H02c@0>1/h61VK>YP6VUV^[9Z/4IP05O7f=P8d0
0VX00c5Z4`02<P0D<C83EXH?I/iVcS7><G8aL/i@cW9N000=l82>SWiROV;e_f^oo`02cP05L/k>cS40
0Ql3XP0;SJ8l?7abcC66cP400lh00`ooo`04o`0<<Lg=HH1QP=DaeC4F0VH01kl1<Oo5mLD01Ql01<fA
cLh49@0<<?i@oDJ6JhI[cXK>1BD00a>5XP057`04<PnF0Ch0000o000Dc_6>P8j0OV9nHZDbJkm[_c7e
<OD2P00<<LfRcHfmO:9l<G8a0/h3J`03I/h?00;>00`acS5P<F2R<J9nJWh3<@045RIVcP=V00>Fc/h0
0/h01hg=SLeQcH000`H02VK>QYJ6ZbJ[9V/4IP0?cV5mP8f0JWiZO_DCmA>o00K>0_D02<ibcW:mT@om
H000381nP7haOS7e_oEb:`9[00@`9/k>0al01/jRHH2>P0:R00J<<LdacP42cP031Poo00Ko00K>XV4a
HC42<P03<FJV008V00L1<A?>aLk500DO00co<I7>L/iV<?h?0IH23`040FI[J`8100=V9BD00bD87`03
<P4003l00010000BlO20OX1n<GhaOP=[0f/b4oD?0/h02F]bJc6=cX3>P004LP0:IV][I/h?cPo>3`?>
00f0cX204h1n<Ghb5RHF008V0P401FH1EP5F00;>00QbcC7=<Lg>c@;>0VH01`mV0DH1AP400R/036H1
3g`lOF5mP65n4`;e00TCmA>oIS0VcRH00/h010l[_KaU0006?8j><V8b0YD02P6EcPo>3bH?9/h37`06
D34aP::01:801C7=cS0?008`00<?ool01Ol030laP80aP=Da<6H`IP8a00KeO_DamBH57`;o00W0cW;>
LPo>3eH00YH02366Jf]VJj^o1BD77`03_`8004000010000:??20SX0bHS9RY@Bo00FU<@mV3`02IP03
3lh?00K=00?>J`l00/h020laIS5V9VK>0W803S5P<F2R<J8aJ]DaeC4F0S400kmV<@02UP03J`mb00;>
00Ab<F1P1C4018H`QS02YP0B9Pm[D79@cU3>?7amO7f5XXDa0S802S42_j]VZfH?U_l`00Go0`0=o`D0
1?l400;o5P001Gj0OS5n00;e00>o<G800/d00lh`9P02LP<O00PaXV60SX2>S@:R00Tac/ha1/h6EPl0
1Ol3cP8a011Q<F5VYVJVoc4CZQ>ZaC0V0Ql01OlO7aoo00><00Eb9@l13`02UP040HI[0@9[0P400ag>
9@039@03OAlO00LO@000044000o`P7j0OS5n<Gh3J`=[</h00Pl2cP8[00JA<I7P<Lh2P004LRK>9P;>
018?cPo>LR]b:j8acZ;>P1>04c42<P03<BHF008V00<19P400UH30@9b00<[<Ld00/d06<k=cW8?IPl1
mPl1o`lVcRKn3`4lOF5mH@<C0_D02Q?e<[mV<9H1U/h`00;o0`02o`030?oo00801?l00`3oo`0900;o
1004oaD000FAXX1R<P02m@030@3>009b0/h00fIb7`027`9b00G=SLfR_@02XP0<OLfRcLhacC3nc_o>
0ol017j0OX02JP0>QC5bLZJUOZGeO_EnmC829P047oooo`<O1BD00lh?UP02UP03IS66009[00J[:oi6
cLh2c@03_GeQ00`O?000044000W`P8j><V8bHYD01;l2UP0=EYH?I/h?cWe@XU1l?002c@03LPmb00:6
015bI/k>IW;>L/haLX3=P360<@02e@0B<MDa5S5V_fJoJ`mV3fIbcW;>0V02<@0=cR_>cS2Vm_h1D<I6
QP023`03IPo>009l00MmO::5XXFR008b00La0[n[3f/?03400_l400;o00<0ool01002o`030?oo00T0
0_l300;o0P02oaD00Z801681UID400;>00=bI/h00al01VJ6?83=P0:m00BR<J;>0/d02Ph?oQ=V<6H`
<Ld5<@0>JS6RXXDb<C9n<WkeO_D59P03<EDO008O1BD03/h?IPmVQVJ6IR_>:c4[0S401/ha<C5mXQ0O
=`00044000g`P8j>OV9nH_FoJkoo00;>00Mbc/k><Lha00>R00^=XS`lO7;=<HK>0@03cP083lib:i5b
XS42c@09HH1QP=DaeC4F009V00bo0C7oaOG5mL9lcG82c@0BTLeb:g8`IS3nD?e6QV^6Jlj60/h048Il
HGeQQJ:5X_DC_c8?UP4c00;o0`04o`030?oo00Go00<0ool02@02o`<00_l200;o5@00196RTKl2m@@0
00<[c/h00/h37`0C3lh??<f=cKg=P<emSG8?LYIV0@029P0:<D7UcX1nP6YRJP<C00=nYGh00Wh031>Z
4klb_bH?<GhaOP<O0bD03<ibcW;>QVH1IP4a0@8a00C><Lha0lh00`lC3`037`@031lI00?o5`000480
00b0OX1n<GhamKoeLR/2J`0=<2K>cS7><LjRHH2>P002XP06S37=<Lh10/h01@H?cP5b00G>00FRHC5Q
<@02<P03<FJV008V00X1<A?>aLk5<<jA0W`03<daTLibcVH`oPl1UP8?00@1IV][0P42IP:V00=QOF40
11<01ODC_c8103D00_l900;o00<0ool00ol:00;o0`02o`800_lF0005XV6RU@401P000f]V7`027`03
QVJ6008?00ebS<fmSLk=c/eb0JHC009F00D`:c0`7P05<@0=JS6RXXFR<C9n<WkeOP029P034`8b008a
00=E<J800al29@0:_6H?IPmVQVH1:`;>00=b<B/00S401<hacS4200033lhO00X02alF0003o`0001H0
00120006?8j><V8b0YD03P6EcPo>3bH?9/hVD35@0S400h2RP004XP05<Lg><0l00S000`on0@023`05
9PlV3c400X002360eC4`IS1V0S401OEnmC7e00<V00k=SLdl`L3>L/ib3lh?EP:F00TaQV][IV^[_hH0
0Pl02gelOHFRQJ8b0[l203H00_lI00Co0`02o`800_lI0003TKl000H000C>7alO0/h00fK>IP023`0:
`Kf0_Lf0cPnF0@9V00d1ARHaJc5liGj0JV9Z00@C00VU<Gin4jXC_c800[l01P4aOS5n<@@O00F<XWc>
3`02cP0<IP4?0781<@7><Lha1P000f/0000>00TO4`000ol0000F00005005o`803Ol600;o4`001Gj0
OS5n00;e00>o<G800/d00lh`9P02LP0;cW9Q<J9QP8j0SXd00Z802c7>cS46cPIF3j/100:[1<h2<@0@
HC5QIZIVY_la4jXCZ/D`9P8`00AFcKg=18`01G:A3`4?00:F00@1QV/10V/20@077Lg>_LemH@044`03
mC:o03P00_l300;o5003o`@01OlS00<O1G803Lh?c/j<SGc>JjK>YVH00UH02TIFJlm6cgb0OX02JP:R
00>5XWh017h01_Fo9RHb_`;e00En<GhaXP037`08P7bRS:;>LPlW00@O1@04o`@00ol300?o0`000ol0
000300Go200001<00_l300Co0P04o`030?oo00P01?lB0005TJ:0HS800_D00`40cP02LP;>00EVL/ib
cP02LP05cHg=X[d00Z804gg=X/g><Ld`o/kocS3>iGj0OX000VX03XDaLW:VYGjUmGkeO_Db12H035Ko
cY5l`7bRcW;>3`>F00=V<HH00V/01Z/[oTK=<@;=00VmOF6RQJ:5<[l0>@06oaD00_l500;o90037`D0
00ib3g8?QVK>7Xe[9/lVc`9F00DCEP7?AP02IP:=00PaJS5ZXZYn<P9n00PbORHC9P8b<@:>00HaOC5m
IC437`03_C7>03D000?o00000`001Ol0003o008000?o00000_l80005o`000?l01`0001800_l400Co
1002o`030?oo00L00_l200;o4P02XP04HP6EU@@00/h0379Vc/iVcVJ6?83=P0:m00BR<J;>0/d02Ph?
oQ=V<6H`<Ld5<@0>JS6RXXDb<C9n<WkeO_D59P0H<EDaXX2RO1j<`<h?IPmVQVJ6IR_>:c4[0S402/ha
<C5mXXFRcPn200<O1`02LP04cPo>3`;>01RVcZK>AP560JI[0JH1O80CHVYROQ=n4c42OP03<AJo00:o
00<1P3400X001C5n<GiQ00@O00=b0000=0000ol000030005o`000?l00P001Ol0003o00T000?o0000
200001800_l300_o00<0ool01`02o`800_lB0004TJ:A_`;e10000b_>cP03cP0E9/h?cPllcHg=_Lf0
cGf=LPmbUVH1008V00Xa@NG>P7j0JV9Z0a<00gjUOP02OP0<4jXC_c:o9PlaOS5n0Wd00j8CO002O00;
L/ibcXIV0FH1<@400S401<hacS43cP033a<?009[P`037`T001UbI/h?iC`V3fH?IUH1IP5V3fJV?8em
OVYn00:Z00AnZWin0c801A<V0S8a00:>00LaOC5mIC5U00@O=P001?l0ool20005o`000?l00P001Ol0
003o00X000?o00001`0001800_l800;o00<0ool00ol800;o0P02oa<000FRHJ:E0@060008JfI[cVJ6
IXH23`0=LXc=_Hg>cLk=LP6V4`02EP05<2/`<1h01C403FXaXZ:5XS4bOS9nmGh00RH00a<2<P02<@03
EC6R00:R00f0XWblIPmV3fJ6IP4[00;>00=b<B/00S401<hacS4200033lh?088011l<00G>01J6c/h1
YP6VEU2AD:J04f4aHGhCOQ<a0Wh0234F_c:o<H0a0X001c5n<GiQ3ld00alf0005o`000?l00P03o`80
1Ol<0003o`0000H0000B00;o6002o`800_lF0003TKl000H00/h01eH`c/iVcVH00Pl02/6mP;g=P<h?
UP42IP0=0DHV<F/aO>EnP6YRJP044`09YC5nOQ>Z4klb00:o00l1<GhaOS5mXQ>RS:9lcPl00/h036H1
3`1b0C41cS7><@H000=[0000P@037a4000T?IPm@3e1V0Pl010001HemP6Yn00:Z00AnZWin13803BH2
XW:mX/ebcG;=LS400P037cD000Go0000o`0H0003o`0000H0000C00;o0`02oa<01OlP0003<79b00Eb
00g>3lk>S8elcV^VcZIV009F00Y6EV_?A/mlP7j00VX2XP03QJ9n00An00Ke_bHV<[l2m@0@OS5n<J9Q
P::0O::<X/ib3iD00alN0004SGf=JP9n00>ZOZX00Wh5<Ph011ld0005o`000?l05@001?l00?l80000
5006oa@00_lY000>LPmb3hIVcQj=JbK?9/l2EP054eH1cdH00VH2S@08<FXaJZ:ZOS82OP08<WhV4bH2
<S42SP08<GdaOFDa_C42_@03<Lh009L011lN0009P1>0<F5n4ghC009n00<F<AH00[l?00@O<P05oaL0
0_l90000F`02LP04cPo>3`;>01RVcZK>AP560JI[0JH1O80CHVYROQ=n4c42OP03<AJo00:o00<1P340
0X002S5n<GiQ<Lg>cG:I00<O7`0018emSFX2OP04ZWjZOPDb00<200003P037eT0001M000ILVK>3nDl
9PmV3fIF0FH1IPmVYSb=OGiZOP02ZP04OZYnOP<b00DC9P8b<@02SP0:<GdaOFDaIC6mD9X00alO000>
O1>0<F5n4ghCOS4F<AH2_a0011mH0000H005cP0FQ/k>0JH1YUI@TE2VP1=Q<F5n4ghC<@9n00Pa5[lb
_c60<@:000PaOS5nH@o=3iX011lP0003?8eZ009n00FZOZYn4`02<P:o4P047eL0001T00093fH?D0m@
IP8?00@000F=OH1ZOP02ZP04OZYnOP@b00dV0Z9b_J;=L/ebcG8a09`00alQ008l00MmOWjZOS:E00<b
00<2<P004P047eH0001a0004SGf=JP9n00>ZOZX00Wh5<ZP00alQ0003?7`C009Q00HCOQ<a4aH2_a@0
11lB00?o@@00074000V04h0aHGhCOQ<00Wh00aHa5P02_jL011lR008l0Wh01:ZE<YD3<P030P0001<0
11lB0003o`000400001a0004SGf=JP9n00BZOZYn1C800`80002U00<O8`001g`l4hdC<A<00S400aJo
_`0F00@O4@000ol000100000L@003W`CP35QOQ=n4gha5S4F0[o=008l0Z800hfE4`02U@039S8001H0
1Al200Co1@03o`800ol30003o`0000D00olb0000LP000cb=JP02OP05ZWjZOQ<00S82_ll00S`01:9U
UC82U@030Kl001L011l30003o`0000@000Oo0000o`3o00800_l:0003o`000340001b008l00MmOWjZ
OS:E00<b00<2<P00YP03obH000QlSHda4c4C9QX011l20003o`0000@000Oo0000o`3o00<000?o0000
20000ol0000a0000LP000cal4`02H@064ghC<A<F0[nY0003o`0002D000PlXVFR<YDb0A`000HO0000
o`02o`<000Oo0000o`3o00<000?o000020000ol0000a0000L`02?09n00BZUC:E0c800`80002W0003
o`0002D000=lSHd00Q<00c4C9P0P0005o`000?l00`03o`030?oo00?o2`000ol0000a0000L`001g`l
4hdC<A<00S400aJo_`2K00Co1003o`<00ol30003o`0000@00_lJ0006?8fRSIDV8@001Ol0003o01D0
00?o0?l0<`0007<00S`2XP03SIDC00:E00<V<P00W0000ol000030005o`000?l00P000ol00002o`L0
00?o00000_lH0006XVFRIIFo8@001Ol0003o01H00_lc0000M002?004XVFE<P:E00<1_`00W0000ol0
00030005o`000?l00P001Ol0003o00/000?o0000?005oaP000?o0000<@0007D000QlSHda4c4C9Yh0
00Co0?oo0P001Ol0003o008000Go0000o`0;0003o`0008d0001e0008?:9UXS:E<P6N0005o`000?l0
0P03o`801Ol:00;oT00007D000=lSHd00Q<00c4C9P2N0005o`000?l05`000ol0002>0000MP001Sb=
XXfE9Yl000Go0000o`0E0004o`00ohl0001f0006XVFRIIFoWP05oaL00_n@0000o`390000o`390000
o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000
o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000
o`390000o`390000o`390000o`390000o`390000o`390000o`390000o`390000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{456, 351.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[StyleBox[
"Evolution Strategies: Three populations on their way to the top",
  FontWeight->"Plain"]], "NumberedFigure",
  CellMargins->{{Inherited, Inherited}, {20, 10}},
  CellLabelPositioning->Automatic,
  CellLabelMargins->{{Inherited, Inherited}, {50, 0}},
  CellFrameLabels->{{Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"], ". "}]], Inherited}, {
      None, Inherited}},
  CellFrameLabelMargins->3,
  FontWeight->"Bold"],

Cell[TextData[{
  "Evolution Strategies have developed sophisticated methods of selection, \
especially when  the evolution scheme involves several sub-populations. \
Figure 1 gives a typical example: Three populations, marked as white, gray \
and black spots, have to independently search for locations of maximum height \
within their \"environment\". The ",
  StyleBox["x",
    FontSlant->"Italic"],
  "- and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-coordinates are encoded on the ES-vectors, with each population \
consisting of 10 members. Initially, the individuals are randomly spread \
within the lower right segment. After 10 generations of iterative selection, \
mutation and recombination, all three populations have evolved to higher \
regions - some individuals being even on their way to the very top (Pop. 2). \
Finally, after 30 generations all populations have obviously converged to one \
of the major viewpoints of the \"mountain region\", showing that Evolution \
Strategies are capable of solving multi-modal optimization problems."
}], "Text"],

Cell["\<\
In the remaining sections we will explore Evolution Strategies in \
great detail. Starting with the data structures of ES-chromosomes we will \
have a closer look at the two major ES-operators: mutation and recombination. \
Another chapter will explain how the basic ES evolution scheme works; from a \
simple (1+1)-ES we will finally make our way up to Meta-ES schemes with \
competing subpopulations. We will conclude this section by several \
ES-experiments in the domain of parameter optimization as exemplified in \
Figure 1.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"RulerBar",
WindowSize->{684, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Evolution Strategy - Introduction"}]]}, {Cell[ 
        TextData[ {"Evolution Strategy - Introduction"}]], Inherited, 
      Inherited}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
Magnification->1,
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[ParentDirectory[]], \
"IEC-Setup"}, "EvolvicaStyle.nb", CharacterEncoding -> "WindowsANSI"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 75, 0, 139, "Title"],
Cell[1805, 54, 107, 2, 62, "Subsubtitle"],
Cell[1915, 58, 1456, 34, 170, "Text"],
Cell[3374, 94, 17, 0, 26, "Text"],
Cell[3394, 96, 95814, 1186, 422, 95696, 1182, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[99211, 1284, 476, 11, 47, "NumberedFigure"],
Cell[99690, 1297, 1073, 19, 206, "Text"],
Cell[100766, 1318, 554, 9, 116, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

